/*
 * Filename: dip_histogram.h
 *
 * Defines and functions for the histogram datastructure
 *
 * AUTHOR
 *    Geert van Kempen, Unilever Research Vlaardingen, 1999
 */

#ifndef DIP_HISTOGRAM_H
#define DIP_HISTOGRAM_H
#ifdef __cplusplus
extern "C" {
#endif

#include "dip_library.h"
#include "dip_string.h"
#include "dip_registry.h"
#include "dip_distribution.h"

/* Definition of DIPlib Histogram */

typedef struct
{
   void *histogram;
} dip__Histogram, *dip_Histogram;

typedef enum
{
   DIP_HGST_IS_RAW    = 0x00,
   DIP_HGST_IS_VALID  = 0x01
} dip_HistogramState;

/* Definitions for Multi-Dimensional Histograms */
#define DIP_MDH_LOWER                 0
#define DIP_MDH_UPPER                 1
#define DIP_MDH_LOWER_UPPER_BINS      2
#define DIP_MDH_LOWER_UPPER_BINSIZE   3
#define DIP__MDH_RANGE_MASK           3
#define DIP_MDH_LOWER_PERCENTILE      4
#define DIP_MDH_LOWER_CENTRE          8
#define DIP_MDH_UPPER_PERCENTILE     16
#define DIP_MDH_UPPER_CENTRE         32
#define DIP_MDH_NO_CORRECTION        64

DIP_ERROR dip_HistogramGetState         ( dip_Histogram, dip_HistogramState * );
DIP_ERROR dip_HistogramValid            ( dip_Histogram, dip_Boolean * );
DIP_ERROR dip_HistogramRaw              ( dip_Histogram, dip_Boolean * );

DIP_ERROR dip_HistogramGetBinSize       ( dip_Histogram, dip_FloatArray *,
                                          dip_Resources );
DIP_ERROR dip_HistogramGetMaximum       ( dip_Histogram, dip_FloatArray *,
                                          dip_Resources );
DIP_ERROR dip_HistogramGetMinimum       ( dip_Histogram, dip_FloatArray *,
                                          dip_Resources );
DIP_ERROR dip_HistogramSetBinSize       ( dip_Histogram, dip_FloatArray );
DIP_ERROR dip_HistogramSetMaximum       ( dip_Histogram, dip_FloatArray );
DIP_ERROR dip_HistogramSetMinimum       ( dip_Histogram, dip_FloatArray );

DIP_ERROR dip_HistogramGetImage         ( dip_Histogram, dip_Image * );
DIP_ERROR dip_HistogramGetDataType      ( dip_Histogram, dip_DataType * );
DIP_ERROR dip_HistogramSetDataType      ( dip_Histogram, dip_DataType );
DIP_ERROR dip_HistogramGetSize          ( dip_Histogram, dip_int * );
DIP_ERROR dip_HistogramGetData          ( dip_Histogram, void ** );
DIP_ERROR dip_HistogramGetDimensions    ( dip_Histogram, dip_IntegerArray *,
                                           dip_Resources );
DIP_ERROR dip_HistogramGetDimensionality( dip_Histogram, dip_int * );
DIP_ERROR dip_HistogramGetID            ( dip_Histogram, dip_int * );
DIP_ERROR dip_HistogramSetName          ( dip_Histogram, dip_String );
DIP_ERROR dip_HistogramGetName          ( dip_Histogram, dip_String *,
                                          dip_Resources );

DIP_ERROR dip_HistogramGetFloat         ( dip_Histogram, dip_FloatArray,
                                          dip_float * );
DIP_ERROR dip_HistogramSetFloat         ( dip_Histogram, dip_FloatArray,
                                          dip_float );
DIP_ERROR dip_HistogramAddFloat         ( dip_Histogram, dip_FloatArray,
                                          dip_float );

DIP_ERROR dip_HistogramNew              ( dip_Histogram *, dip_Resources );
DIP_ERROR dip_HistogramFree             ( dip_Histogram * );
DIP_ERROR dip_HistogramForge            ( dip_Histogram );
DIP_ERROR dip_HistogramStrip            ( dip_Histogram );

DIP_ERROR dip_HistogramCopyProperties   ( dip_Histogram, dip_Histogram );
DIP_ERROR dip_HistogramAssimilate       ( dip_Histogram, dip_Histogram );
DIP_ERROR dip_HistogramFill             ( dip_Histogram, dip_Image, dip_Image );
DIP_ERROR dip_ImageHistogramCount       ( dip_Image, dip_Image, dip_Histogram );


DIP_ERROR dip_ImageToHistogram          ( dip_Image, dip_Histogram, dip_Image,
                                          dip_float, dip_float, dip_float,
                                          dip_Boolean );
DIP_ERROR dip_HistogramToImage          ( dip_Histogram, dip_Image );

/* Registry functions for the dip_Histogram data structure */
DIP_ERROR dip_HistogramRegistryList  ( dip_IntegerArray *, dip_Resources );
DIP_ERROR dip_HistogramRegistryGet   ( dip_int, dip_Histogram * );
DIP_ERROR dip_HistogramRegistryFree  ( dip_int );

dip_Error dip_HistogramInitialise    ( void );

/* Multi-dimensional histogram */
DIP_ERROR dip_MultiDimensionalHistogram( 
              dip_Image, dip_BooleanArray, dip_Image, dip_Distribution,
              dip_IntegerArray, dip_FloatArray,
              dip_FloatArray, dip_FloatArray );
DIP_ERROR dip_MultiDimensionalHistogramMap( 
              dip_Image, dip_BooleanArray, dip_Image, dip_Image, dip_Image,
              dip_IntegerArray, dip_FloatArray,
              dip_FloatArray, dip_FloatArray );
DIP_ERROR dip_HistogramRangeConvert(
              dip_float *, dip_float *, dip_int *, dip_int,
              dip_float, dip_float, dip_float, dip_float );
DIP_ERROR dip_ArMultiDimensionalHistogram( 
              dip_ImageArray, dip_Image, dip_Distribution, dip_IntegerArray,
              dip_FloatArray, dip_FloatArray, dip_FloatArray );
DIP_ERROR dip_ArMultiDimensionalHistogramMap( 
              dip_ImageArray, dip_Image, dip_Image, dip_Image,
              dip_IntegerArray, dip_FloatArray, dip_FloatArray,
              dip_FloatArray );

#ifdef __cplusplus
}
#endif
#endif
