/*
 * Filename: dip_portability.h
 *
 * (C) Copyright 1995-1997               Pattern Recognition Group
 *     All rights reserved               Faculty of Applied Physics
 *                                       Delft University of Technology
 *                                       Lorentzweg 1
 *                                       2628 CJ Delft
 *                                       The Netherlands
 *
 * Contact: Dr. ir. Lucas J. van Vliet
 * email  : lucas@ph.tn.tudelft.nl
 *
 * Some portability  problems are solved in this include file
 *
 */

#ifndef DIP_PORTABILITY_H
#define DIP_PORTABILITY_H
#ifdef __cplusplus
extern "C" {
#endif

#define DIP_EXPORT

#ifndef DEBUG
#ifndef NDEBUG
#define NDEBUG
#endif
#endif

#include <string.h> /* for memset(), dip__thclass.c */

#define DIP_PORT_LN2   0.693147180559945309417232121458176568075500134
#define DIP_PORT_LN10  2.302585092994045684017991454684364207601101489
#define DIP_PORT_LN2_R 1.442695040888963407359924681001892137426645954

/* on sun4, GCC doesn't have printf prototypes, we provide them here */
#ifdef SUNOS41
   #define DIP_HAS_POSIX_TIME
   #ifdef GCC
   #include <stdio.h>
   #include <sys/stdtypes.h>
   #include <sys/param.h>
   #include <sys/types.h>
   #include <sys/time.h>
   #include <sys/times.h>
   time_t time(time_t *);
   long clock( void );
   #ifndef CLK_TCK
      #define CLK_TCK   HZ
   #endif
   #ifndef CLOCKS_PER_SEC
      #define CLOCKS_PER_SEC (1000000)
   #endif
   int printf(const char *, ...);
   int fprintf(FILE *, const char *, ...);
   int fclose(FILE *);
   int fscanf(FILE *, char *, ...);
   void fflush(FILE * );
   int fread(char *, int, int, FILE *);
   int fwrite(char *, int, int, FILE *);
   int fseek(FILE *, long, int );
   long fteel(FILE * );
   int rewind( FILE *);
   /* endif of GCC */
   #endif
   /* endif of SUNOS41 */
#endif

#ifdef SOLARIS24
#define _POSIX_SOURCE 1
/* endif of SOLARIS24 */
#endif

#ifdef SOLARIS25
#define _POSIX_SOURCE 1
/* endif of SOLARIS25 */
#endif


#ifdef IRIX5
#define _POSIX_SOURCE 1
/* endif of IRIX5 */
#endif

#ifdef IRIX6
/* these three lines are needed for DIPlib's POSIX timer, GvK */
/* However, Irix6.2 does not think it is POSIX */
#ifndef _SGI_SOURCE
#define _SGI_SOURCE
#endif
#include <limits.h>
#include <unistd.h>
#include <sys/types.h>
#define _POSIX_SOURCE 1

/* endif of IRIX6 */
#endif

#ifdef LINUX
#define _POSIX_SOURCE 1
/* endif of LINUX */
#endif

#ifdef HPUX10
#define _POSIX_SOURCE 1
#ifdef __GNUC__
#undef __GNUC__
#endif
#define DIP_PORT_HAS_MALLOPT
/* endif of HPUX10 */
#endif

#ifdef AIX4
#define _POSIX_SOURCE 1
/* endif of AIX4 */
#endif

#ifdef WIN32 /* portability for Windows NT & 95 systems */
#define _POSIX_SOURCE 1
#define strcasecmp stricmp

#define DIP_PORT_HAS_NO_EXP2
#define DIP_PORT_HAS_NO_EXP10
#define DIP_PORT_HAS_NO_LOG2

#define DIP_PORT_LN2   0.693147180559945309417232121458176568075500134
#define DIP_PORT_LN10  2.302585092994045684017991454684364207601101489
#define DIP_PORT_LN2_R 1.442695040888963407359924681001892137426645954

/* TimerSet() and TimerGet() don't work for now - GvK June 1998 */
#define DIP_PORT_HAS_NO_TIME 1

#undef DIP_EXPORT
#ifdef DIP_DLL_CREATE
#define DIP_EXPORT __declspec(dllexport)
#else
#define DIP_EXPORT __declspec(dllimport)
#endif

#endif /* endif of WIN32 */

#ifdef MACINTOSH /* portability for MacOS */
#define _POSIX_SOURCE 1
#define DIP_PORT_HAS_NO_TIME 1
#define DIP_PORT_HAS_NO_EXP2
#define DIP_PORT_HAS_NO_EXP10
#define DIP_PORT_HAS_NO_LOG2
#define DIP_PORT_LN2   0.693147180559945309417232121458176568075500134
#define DIP_PORT_LN10  2.302585092994045684017991454684364207601101489
#define DIP_PORT_LN2_R 1.442695040888963407359924681001892137426645954
#endif /* endif of MACINTOSH */

#ifndef DIP_PORT_HAS_NO_TIME
   #ifndef DIP_HAS_POSIX_TIME
      #ifdef _POSIX_SOURCE
         #define DIP_HAS_POSIX_TIME
      #endif
   #endif
#endif

#ifndef DIP_VOID_PTR_OFFSET
   #define DIP_VOID_PTR_OFFSET( a, b, o, t, s) (a)=(void *)((char *)(b)+(o)*(s))
/*
   #define DIP_VOID_PTR_OFFSET( a, b, o, t, s) (a) = (b); \
      DIPXJ( dip_AddOffsetToPointer( &(a), (o), (t)));
*/
#endif

#define DIP_ERROR DIP_EXPORT dip_Error

#include <assert.h>

#ifdef __cplusplus
}
#endif
#endif
