/*
 * Filename: dipio_tiff.h
 *
 * (C) Copyright 2000-2004               Pattern Recognition Group
 *     All rights reserved               Faculty of Applied Physics
 *                                       Delft University of Technology
 *                                       Lorentzweg 1
 *                                       2628 CJ Delft
 *                                       The Netherlands
 *
 * Contact: Dr. ir. Lucas J. van Vliet
 * email : lucas@ph.tn.tudelft.nl
 *
 */

#ifndef DIPIO_TIFF_H
#define DIPIO_TIFF_H

#ifdef __cplusplus
extern "C" {
#endif

/* These are used in reading/writing TIFF. The values are the not same as the
 * corresponding "Compression" tag values. */
typedef enum {
	DIPIO_CMP_TIFF_DEFAULT = 0,
	DIPIO_CMP_TIFF_NONE = 1,
	DIPIO_CMP_TIFF_LZW,
	DIPIO_CMP_TIFF_PACKBITS,
	DIPIO_CMP_TIFF_THUNDERSCAN,
	DIPIO_CMP_TIFF_NEXT,
	DIPIO_CMP_TIFF_CCITTRLE,
	DIPIO_CMP_TIFF_CCITTRLEW,
	DIPIO_CMP_TIFF_CCITTFAX3,
	DIPIO_CMP_TIFF_CCITTFAX4,
	DIPIO_CMP_TIFF_DEFLATE,
	DIPIO_CMP_TIFF_ADOBE_DEFLATE
} dipio_TIFFCompression;

DIPIO_EXPORT dip_int dipio_ReadTIFFID  ( void );
DIPIO_EXPORT dip_int dipio_WriteTIFFID ( void );

DIPIO_ERROR dipio_ImageReadTIFF        ( dip_Image, dip_String,
                                         dipio_PhotometricInterpretation * );
DIPIO_ERROR dipio_ImageReadTIFFInfo    ( dipio_ImageFileInformation, dip_String );
DIPIO_ERROR dipio_ImageIsTIFF          ( dip_String, dip_Boolean * );
DIPIO_ERROR dipio_ImageWriteTIFF       ( dip_Image, dip_String,
                                         dipio_PhotometricInterpretation,
                                         dipio_TIFFCompression );
DIPIO_ERROR dipio_CompressionSetTIFF   ( dipio_TIFFCompression );


/* should only be called by dipio_Initialise() */
dip_Error dipio_RegisterReadTIFF( dip_int * );
dip_Error dipio_RegisterWriteTIFF( dip_int * );
dip_Error dipio_InitialiseTIFF( void );

#ifdef __cplusplus
}
#endif


#endif /* DIPIO_TIFF_H */
