%CAT   Concatenate images.
%   CAT(DIM,A,B) concatenates the images A and B along
%   the dimension DIM.
%   CAT(1,A,B) is the same as [A,B].
%   CAT(2,A,B) is the same as [A;B].
%
%   CAT(DIM,A1,A2,A3,A4,...) concatenates the input images
%   A1, A2, etc. along the dimension DIM.
%
%   If any of the inputs is a dip_image_array, its images are
%   concatenated horizontally. CAT always produces a single
%   dip_image.
%
%   CAT(DIM,A) concatenates the images in the dip_image_array
%   A along the dimension DIM.

% (C) Copyright 1999-2002               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Cris Luengo, July 2000.
% 15 November 2002: Fixed binary images to work in MATLAB 6.5 (R13)

function out = cat(dim,varargin)
if nargin < 2, error('Erroneus input.'); end
if builtin('isa',dim,'dip_image'), error('Erroneus input.'); end
n = nargin-1;
if n > 1
   in = cell(1,n);
   in_type = cell(1,n);
   for ii=1:n
      if ~builtin('isa',varargin{ii},'dip_image')
         varargin{ii} = dip_image(varargin{ii});
      end
      if prod(builtin('size',varargin{ii})) > 1
         % concatenate dip_image_array into single image;
         res = cat(1,varargin{ii});
         in{ii} = res.data;
         in_type{ii} = res.dip_type;
      else
         in{ii} = varargin{ii}.data;
         in_type{ii} = varargin{ii}.dip_type;
      end
   end
   out_type = in_type{1};
   for ii=2:n
      % Find the correct output datatype
      out_type = di_findtypex(out_type,in_type{ii});
   end
   for ii=1:n
      % convert to the output type
      if ~strcmp(in_type{ii},out_type)
         in{ii} = di_convert(in{ii},di_mattype(out_type));
      end
   end
   if dim == 1
      dim = 2;
   elseif dim == 2
      dim = 1;
   end
   try
      out = dip_image(builtin('cat',dim,in{:}),out_type);
   catch
      error(di_firsterr)
   end
else
   % if builtin('isa',varargin{ii},'dip_image')    ALWAYS TRUE
   n = prod(builtin('size',varargin{1}));
   if n > 1
      %??? Should we want to concatenate in the same positions as
      %    the images are in the dip_image_array?
      in = cell(1,n);
      in_type = cell(1,n);
      for ii=1:n
         in{ii} = varargin{1}(ii).data;
         in_type{ii} = varargin{1}(ii).dip_type;
      end
      out_type = in_type{1};
      for ii=2:n
         % Find the correct output datatype
         out_type = di_findtypex(out_type,in_type{ii});
      end
      for ii=1:n
         % convert to the output type
         if ~strcmp(in_type{ii},out_type)
            in{ii} = di_convert(in{ii},di_mattype(out_type));
         end
      end
      if dim == 1
         dim = 2;
      elseif dim == 2
         dim = 1;
      end
      try
         out = dip_image(builtin('cat',dim,in{:}),out_type);
      catch
         error(di_firsterr)
      end
   else
      out = varargin{1};
   end
end
