% CHANGE_XYZ   Change the whitepoint of the XYZ colorspace.
%
%  SYNOPSIS:
%     image_out = change_xyz(image_in, new_xyz)
% 
%  DEFAULTS:
%     new_xyz = [0.9505 1 1.0888]  (D65 white)
% 
%  DESCRIPTION:
%     The whitepoint of the input image is changed into the new value (XYZ_new). 
%     This is done by assuming that the values in CIELAB should be the same for
%     the input image with the old reference white and the output image with 
%     the new reference white.
%     Note the difference with SET_XYZ. In change_xyz the pixel values of the 
%     input image are changed due to the change in the white reference, whereas 
%     in set_xyz only the reference white is changed.
%
%  EXAMPLE:
%     a = change_xyz( readcolorim, [0.9642 1 0.8249])  %(D50 white)

% (C) Copyright 1999-2002               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Judith Dijk, June 2002.

function out = change_xyz( in, XYZ_out)

if nargin < 1, error('Need an input argument.'); end

if ~iscolor(in), error('The input image should be a color image'); end

ori_col = colorspace(in);
xyz = colorspace(in, 'xyz');

if isfield( in(1).color, 'xyz')
   XYZ_in = in(1).color.xyz;
else
   XYZ_in = [.9505 1 1.0888];
end
if( nargin < 2)
   XYZ_out = [.9505 1 1.0888]; % standard d65-2
end

tmp1 = xyz(1).*XYZ_out(1)./XYZ_in(1);
tmp2 = xyz(2).*XYZ_out(2)./XYZ_in(2);
tmp3 = xyz(3).*XYZ_out(3)./XYZ_in(3);

out = joinchannels( 'XYZ', tmp1, tmp2, tmp3);
for i=1:3
   out(i).color = xyz(1).color;
   out(i).color.xyz = XYZ_out;
end
out = colorspace( out, ori_col );
