%CURL  Calculates the rotation of a 2D/3D vector image.
%
% image_out = curl(image_in, sigma)
%
% PARAMETER:
%  image_in: must be a vector image 
%
% DEFAULT:
%  sigma = 1

% (C) Copyright 1999-2001               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, May 2001


function out =curl2(in,sigma)

if nargin < 2
   sigma = 1;
end
if ~isnumeric(sigma)
   error('Sigma parameter must be numeric.')
   % This assures that IN is a dip_image
end
if ~isvector(in)
   error('Input image not dip_image vector.')
end

dims = length(in);% vector dimensions
sigmas = sigma(:)';
if length(sigmas) == 1
   sigmas = repmat(sigmas,1,dims);
elseif length(sigmas) < dims
   sigmas = repmat(sigma(end),1,dims);
   sigmas(1:length(sigma)) = sigma;
elseif length(sigmas) > dims
   sigmas = sigmas(1:dims);
end
sx = sigmas(1);
sy = sigmas(2); 

switch dims
	case 2
      %fprintf('case 2D\n');
      if ndims(in(1)) > dims
         fprintf('Assuming input 2D time series: only processing the image dimensions.\n');
         out = dip_gauss(in(2),[1 1 0],[sx sy 0],[1 0 0]) -...
               dip_gauss(in(1),[1 1 0],[sx sy 0],[0 1 0]); 
      else
		   out = dx(in(2),sx)-dy(in(1),sy);
	   end
   case 3
		%fprintf('case 3D\n');
      sz = sigmas(3);
		out = dip_image('array',[3 1]);
		out(1) = dy(in(3),sy)-dz(in(2),sz);
		out(2) = dz(in(1),sz)-dx(in(3),sx);
		out(3) = dx(in(2),sx)-dy(in(1),sy)
	otherwise
		error('Curl only for 2D/3D vectors.')	
end
