%DIP_ARRAY   Extracts the data array from a dip_image.
%   A = DIP_ARRAY(B) converts the dip_image B to a MATLAB
%   array without changing the type. A can therefore become
%   an array of type other than double, which cannot be used
%   in most MATLAB functions. Use A = DOUBLE(B) to get an
%   array of type double.
%   [A1,A2,A3,...An] = DIP_ARRAY(B) returns the n images in the
%   dip_image_array B in the arrays A1 through An.

% (C) Copyright 1999-2000               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Cris Luengo, March 1999.
% 1 June 2000: Now returns each image in the dip_image_array in
%              a separate output argument (instead of giving an error).

function varargout = dip_array(in)
n = prod(builtin('size',in));
if nargout ~= n & ~(n == 1 & nargout <= 1)
   error('The number of output arguments must match the number of images in the array.')
end
varargout = cell(1,n);
[varargout{:}] = deal(in.data);
