%DIVERGENCE  Calculates the divergence of a vector image.
%
% image_out = divergence(image_in, sigma)
%
% PARAMETER:
%  image_in: must be a vector image
%
% DEFAULT:
%  sigma = 1

% (C) Copyright 1999-2001               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, May 2001
% March, 2003, added iterative gaussian filtering for large sigmas

function out = divergence(in,sigma)

if nargin < 2
   sigma = 1;
end
if ~isnumeric(sigma)
   error('Sigma parameter must be numeric.')
   % This assures that IN is a dip_image
end
if ~isvector(in)
   error('Input image not dip_image vector.')
end



vdim = length(in); %vector dimensions
dim  = ndims(in(1)); %image dimensions per components

%fprintf('vector dim: %d, image dim: %d\n',vdim, dim);
nd = sum(builtin('size',in)>1);
if nd > 1 | nd == 0
   error('Divergence only defined for vector images.');
end

sigmas = sigma(:)';
if length(sigmas) == 1
   sigmas = repmat(sigmas,1,dim);
elseif length(sigmas) < dim
   sigmas = repmat(sigma(end),1,dim);
   sigmas(1:length(sigma)) = sigma;
elseif length(sigmas) > dim
   sigmas = sigmas(1:dim);
end


if vdim < dim
   %time series, no blurring in the z-direction wanted
   fprintf('Assuming input time series: only processing the image dimensions.\n');
   process = repmat(1,1,vdim);
   process(vdim+1:dim) = 0;
elseif vdim > dim
   error('Why would you have more vector dims that image dims?');
else
   process = repmat(1,1,dim);
end

out = dip_image('zeros',size(in(1)));
parOrder = repmat(0,1,dim);
sigsz = prod(sigmas)/dim;
fto = 3*ones(size(sigmas));
for ii = 1:vdim
   parOrder(ii) = 1;
   if sigsz < 5
      out = out + dip_gauss(in(ii),process,sigmas,parOrder);
   else
      out = out + dip_gaussiir(in(ii),process,sigmas,parOrder,fto,2);
   end
   parOrder(ii) = 0;
end



