%  GET_XYZ   Retrieve the whitepoint of the XYZ colorspace.
% 
%  SYNOPSIS:
%     xyz_image_in = get_xyz(image_in)
% 
%  DEFAULTS:
%
%  DESCRIPTION:
%     The whitepoint of the input image is retreived. If the input image does
%     not contain this information yet, the standard whitepoint 
%     [0.9505 1 1.0888]  (D65 white) is returned. 
%
%  EXAMPLE:
%    xyz_out = get_xyz( readcolorim)
%

% (C) Copyright 1999-2002               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Judith Dijk, June 2002.

function out = get_xyz( in )

if nargin < 1, error('Need an input argument.'); end

if isempty(in(1).color), error('The input image should be a color image'); end

if isfield(in(1).color, 'xyz')
   out = in(1).color.xyz;
else
   out = [0.9505 1 1.0888];
end

