%GRADIENT   Gradient vector of an image.
%   GRADIENT(A,SIGMA) returns the gradient vector of a real valued,
%   scalar image. SIGMA is the Gaussian smoothing. The returned type
%   is an N-by-1 tensor image, where N is the dimensionality of A.

% (C) Copyright 1999-2000               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, August 2000.
% Cris Luengo, 21 September 2000: SIGMA is now allowed to be any size vector.

function out = gradient(in,sigma)

if nargin < 2
   sigma = 1;
end
if ~isnumeric(sigma)
   error('Sigma parameter must be numeric.')
   % This assures that IN is a dip_image
end
if prod(builtin('size',in)) ~= 1
   error('Input image must be scalar.')
end
if ~isreal(in.data)
   error('Input image must be real.')
end

dim = ndims(in);
out = dip_image('array',[dim,1]);
sigmas = sigma(:)';
if length(sigmas) == 1
   sigmas = repmat(sigmas,1,dim);
elseif length(sigmas) < dim
   sigmas = repmat(sigma(end),1,dim);
   sigmas(1:length(sigma)) = sigma;
elseif length(sigmas) > dim
   sigmas = sigmas(1:dim);
end
parOrder = repmat(0,1,dim);
process = repmat(1,1,dim);
for ii = 1:dim
   parOrder(ii) = 1;
   out(ii) = dip_gauss(in,process,sigmas,parOrder);
   parOrder(ii) = 0;
end
