%  HUECORR   changing the hue in the HSV colorspace
% 
%  SYNOPSIS:
%     image_out = function(image_in, fact, root1, root2, root3, shift_val)
% 
%  DEFAULTS:
%     fact      : -0.1125
%     root1     : 0
%     root2     : 2
%     root3     : 2
%     shift_val : 0.75
% 
%  DESCRIPTION:
%     The hue (in HSV) is transformed with the following formula:
%        h_out = 3* (h+shift_val + fact( h+shift_val-root1) (h+shift_val-root2)
%            (h+shift_val-root3))
%     The goal of this transformation is to obtain a better sampling of the
%     colorcircle. A polynomial is added to the hue, with certain zero crossings
%     on which the hue will remain constant.
% 
%  EXAMPLE:
%    a=huecorr(readcolorim,-0.1125,0,2,2, 0.75)
%

% (C) Copyright 1999-2002               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Piet W. Verbeek
% implemented in dipimage: Judith Dijk, June 2002.

function out=huecorr(in,fact,root1,root2,root3, shift_val)
if nargin < 2, fact = -0.1125; end
if nargin < 3, root1 = 0; end
if nargin < 4, root1 = 2; end
if nargin < 5, root1 = 2; end
if nargin < 6, shift_val = 0.75; end
   
ori_col = colorspace(in);
ori_xyz = get_xyz(in);
cc = colorspace(in, 'HSV');
cc(1) = shift_cal+cc(1);
cc(1) = 3*polycorr(cc(1)/3,fact,root1,root2,root3);
out = cc;
for i=1:3
   out(i).color = in(1).color;
   out(i).color.space = 'HSV';
end
out = colorspace(out, ori_col);

%polycorr
function out = polycorr( in, fact, root1, root2, root3)
out = in + fact * ( in - root1 ) * (in - root2) * ( in - root3 );
