%  ISO_LUMINANCE_LINES plot lines with same luminance in color image
% 
%  SYNOPSIS:
%     image_out = iso_luminance_lines(image_in, number_of_lines)
% 
%  DEFAULTS:
%     number_of_lines = 10
% 
%  DESCRIPTION:
%     A number of curves (lines) connecting points with the same luminance are 
%     drawn in the input image.
%   
%  EXAMPLE: a = iso_luminance_lines( readcolorim, 10)
%   

% (C) Copyright 1999-2002               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Piet W. Verbeek
% implemented in dipimage: Judith Dijk, June 2002.

function out = iso_luminance_lines( in, number)

if nargin < 1, error('Need an input argument.'); end
if nargin < 2,number = 10; end

if ~iscolor(in)
   Y8 = in * number;
   tmp = threshold( Y8 - floor( Y8 ), 'fixed', 0.015 * number);
   out = tmp * in;
else
   ori_col = colorspace(in);
   Yxy_in = colorspace( in,'Yxy');
   Y8 = Yxy_in(1) * number;
   tmp = threshold( Y8 - floor( Y8 ), 'fixed', 0.015 * number);
   out = joinchannels( 'Yxy', tmp * Yxy_in(1), Yxy_in(2), Yxy_in(3));
   for i=1:3
      out(i).color = Yxy_in(1).color;
   end
   out = colorspace( out, ori_col);
end