% LUMINANCE_STEERED_EROSION erosion on color image with luminance ordering
%
% SYNOPSIS
%   image_out = luminance_steered_erosion(image_in, size)
%
% DEFAULTS:
%   size  : 7
%
% DESCRIPTION: An erosion on the color image is determined in which the 
%   ordering is taken as the smallest luminance value in the neighbourhood. 
%   So, in the given neighbourhood the points with the smallest luminance is
%   determined, and then the colors of that points are given in the output
%   point.
%
% EXAMPLE 
%   a = luminance_steered_erosion( readcolorim, 7)
%

% (C) Copyright 1999-2002               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Piet W. Verbeek
% implemented in dipimage: Judith Dijk, August 2002.

function out = luminance_steered_erosion(in,size, colspace)
if nargin < 1, error('Need an input argument.'); end
if ~iscolor(in), error('the input image should be a colorimage'); end 
if nargin < 2,   size = 7; end

Y = colorspace(in, 'grey');
out = in;
s = builtin('size',in);
for ii=1:s(1)
   out(ii) = dip_generalisedkuwahara(in(ii),Y,[1],[size,size],'elliptic',1);
   out(ii).color = in(1).color;
end
