%  MON_XYZ2RGB   xyz to rgb transformation for a calibrated monitor
% 
%  SYNOPSIS:
%     image_out = mon_xyz2rgb(image_in, rgb_xyz, gammaval)
% 
%  DEFAULTS:
%     rgb_xyz  : [3.50969    -1.74031  -0.545358
%					  -1.06828     1.97725   0.0345393
%					   0.0552852  -0.196645  1.05062]^(-1);
%     gammaval : [1.0 1.0 1.0];
% 
%  DESCRIPTION: 
%     This function is used to transform RGB values to XYZ values for a
%     calibrated monitor. 
%    
%  EXAMPLE:
%
   
% (C) Copyright 1999-2002               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Judith Dijk, June 2002.

function out = mon_xyz2rgb( in, rgb2xyz_mat, gamma)

if nargin < 1, error('Need an input image'); end
if ~iscolor(in), error('Need a color input image'); end
if ~strcmp( colorspace(in), 'XYZ'), 
   error('The input image should be in the XYZ colorspace'); end
if(nargin < 3), gamma = [1.0 1.0 1.0]; end
s = size( gamma);
if( s(1)>1), gamma = gamma'; end
s = size( gamma);
if( s(1)==1 & s(2)==1), gamma(1, 2:3) = gamma(1); end
s = size(gamma);
if( s(1)~=1 | s(2)~=3), error('Gamma should be one or three values\n'); end

if( nargin < 2)
	rgb2xyz_mat = [3.50969  -1.74031  -0.545358
						-1.06828  1.97725  0.0345393
						0.0552852  -0.196645  1.05062]^(-1);
end

xyz_old = get_xyz(in);
out = dip_image('array',[3,1]);
out(:) = in; % to make sure that the array is a column vector.
out = rgb2xyz_mat^(-1)*out;

out(1) = out(1).^gamma(1, 1).*255;
out(2) = out(2).^gamma(1, 2).*255;
out(3) = out(3).^gamma(1, 3).*255;

out = joinchannels( 'RGB', out(1), out(2), out(3));
for i=1:3
   out(i).color = in(1).color;
   out(i).color.space = 'RGB';
end
