%NORM   Computes the (Eucledian) norm of a tensor image.
%   NORM(V,P) = sum(abs(a).^p)^(1/p)
%   NORM(V)   = norm(v,2) default P=2 eucledian

% (C) Copyright 1999-2000               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, November 2000.
% Nov 2002, added norm for tensor images, being the Froebius norm

function out = norm(a,p)
if nargin == 1
   p = 2;
elseif ~isnumeric(p) | prod(size(p))~=1
   error('Exponent must be a scalar.');
end
if ~istensor(a)
   error('Input image not dip_image tensor.')
end
nd = sum(builtin('size',a)>1);

if nd ==0;
  out = a;
else
   if isinf(p)
      if p>0 % p==Inf
         out = max(abs(a));
      else   % p==-Inf
         out = min(abs(a));
      end
   else
      out = sum(abs(a).^p)^(1/p);
   end
end
