% OUT_OF_GAMUT  Determine which colors of an image are outside the gamut.
%
%  SYNOPSIS:
%   image_out = out_of_gamut( image_in, gamut_data)
% 
%  DEFAULTS:
%   gamut_data: standard RGB gamut (D65, 2 degrees observer)
% 
%  DESCRIPTION:
%   The output of this function is a binary image in which a 1 represents pixels
%   that are outside the provided gamut. This means that these pixels cannot be
%   displayed on the device to which the gamut belongs. 
%   
%  EXAMPLE:
%   a = out_of_gamut( change_chroma( readcolorim, 2))
%

% (C) Copyright 1999-2002               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Judith Dijk, June 2002.

function	out = out_of_gamut( in, gamut_data)

if nargin < 1, error('Need an input argument.'); end
if nargin < 2 | isempty(gamut_data), gamut_data = make_gamut; end
if( ~iscolor(in)) error('The input image should be a color image.'); end;  

clipping = 'chord_clip';

lab_in = colorspace(in, 'lab');

clipped_im = gamut_mapping( lab_in, clipping, gamut_data );

% if the clipped im is different than the original, the pixels are out-of-gamut.
out = abs( clipped_im(1) - lab_in(1)) > 0.000001;
% out = clipped_im(1) ~= lab_in(1);


   




 
 


