%DIP_TYPE = DI_DIPTYPE(IN)
%    Determines the DIPlib data type associated with the data type
%    of the array IN.
%
% Note: There is no extended checking. So unknown data types can
% pass unnoticed (as will non-numeric types). This should not be a
% problem, since this function is private.

% (C) Copyright 1999-2002               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Cris Luengo, May 2000.
% 15 November 2002: Fixed binary images to work in MATLAB 6.5 (R13)

function dip_type = di_diptype(in)
if islogical(in)
   dip_type = 'bin';
else
   dip_type = class(in);
   if ~isreal(in)
      if strcmp(dip_type,'double')
         dip_type = 'dcomplex';
      else
         dip_type = 'scomplex';
      end
   else
      switch dip_type
         case 'int8'
            dip_type = 'sint8';
         case 'int16'
            dip_type = 'sint16';
         case 'int32'
            dip_type = 'sint32';
         case 'single'
            dip_type = 'sfloat';
         case 'double'
            dip_type = 'dfloat';
      end
   end
end
