%XYZ2LAB   Convert color image from XYZ to L*a*b*.

% (C) Copyright 1999-2001               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Judith Dijk, July 2000.
% 28 June 2001: Somewhat rewritten by Cris.
% June 2002: image.color.xyz added -> is overruled by 2nd argument (Judith)

function out = xyz2lab(in, xyz_set)

if prod(builtin('size',in)) < 3
   warning('Expected three components. No conversion done.')
   out = in;
end

XYZ_white = [0.9505,1,1.0888]; % D65, 2 graden waarnemer, standaard

if isfield(in(1).color, 'xyz')
   XYZ_white = in(1).color.xyz;
end

if( nargin > 1)
   XYZ_white = xyz_set;
end

Xn = XYZ_white(1);
Yn = XYZ_white(2);
Zn = XYZ_white(3);

X = double(in(1))/Xn;
Y = double(in(2))/Yn;
Z = double(in(3))/Zn;

L = zeros(size(X));
a = L;
b = L;

magic_number = 0.008856;

I = find(Y<=magic_number);   % Assuming I are few elements
fY = Y.^(1/3);
fY(I) = 7.787*Y(I)+(16/116);

L = 116*(fY)-16;

I = find(X<=magic_number);
a = X.^(1/3);
a(I) = 7.787*X(I)+(16/116);
a = (a-fY)*500;

I = find(Z<=magic_number);
b = Z.^(1/3);
b(I) = 7.787*Z(I)+(16/116);
b = (fY-b)*200;

out = di_joinchannels(in(1).color,'L*a*b*',L,a,b);
