%SIZE   Size of the image.
%   SIZE(B) returns an N-D array containing the lengths of
%   each dimension in the image in B.
%
%   SIZE(B,DIM) returns the length of the dimension specified
%   by the scalar DIM.
%
%   [M,N] = SIZE(B) returns the number of rows and columns in
%   separate output variables. [M1,M2,M3,...,MN] = SIZE(B)
%   returns the length of the first N dimensions of B.
%
%   If B is an array of images, SIZE returns the dimensions of
%   the array itself, not of the images.

% (C) Copyright 1999-2001               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Cris Luengo, May-June 1999.
% 5 January 2001: SIZE(A) now returns NDIMS(A) elements.
% 20 April 2001: No, it didn't. Now it does.

function [varargout] = size(in,dim)
if nargin > 1
   if ~builtin('isa',in,'dip_image') % means dim must be of type dip_image!
      error('Dimension number must be a non-negative integer.')
      % This is a copy of the error message of the original SIZE.
   end
end
if (prod(builtin('size',in)) ~= 1)
   if nargout > 1
      if nargin ~= 1, error('Unknown command option.'); end
      s = builtin('size',in);
      for ii=1:min(length(s),nargout)
         varargout{ii} = s(ii);
      end
      for ii=ii+1:nargout
         varargout{ii} = 1;
      end
   else
      if nargin == 1
         varargout{1} = builtin('size',in);
      else %nargin == 2
         try
            varargout{1} = builtin('size',in,dim);
         catch
            error(lasterr)
         end
      end
   end
else
   if nargout > 1
      if nargin ~= 1, error('Unknown command option.'); end
      if ~isempty(in.data)
         s = size(in.data);
         if length(s)>1
            s = s([2,1,3:end]);
         end
         for ii=1:min(length(s),nargout)
            varargout{ii} = s(ii);
         end
         for ii=ii+1:nargout
            varargout{ii} = 1;
         end
      else
         for ii=1:nargout
            varargout{ii} = 0;
         end
      end
   else
      if ~isempty(in.data)
         if nargin == 1
            s = size(in.data);
            if in.dims==0
               s = [];
            elseif in.dims==1
               s = prod(s);
            elseif length(s)<in.dims
               s = [s,ones(1,in.dims-length(s))];
            end
            if length(s)>1
               s = s([2,1,3:end]);
            end
            varargout{1} = s;
         else %nargin == 2
            if dim == 1
               dim = 2;
            elseif dim == 2
               dim = 1;
            end
            try
               varargout{1} = size(in.data,dim);
            catch
               error(lasterr)
            end
         end
      else
         varargout{1} = [];
      end
   end
end
