%SLICE_OP   Apply a function to all slices in the last image dimension
%
%  With this function handling operation on time series
%  become much easier, where the operation should only be done
%  per time slice.
%
%  SYNOPSIS:
%   image_out = slice_op('function',image_in, par1, par2,...)
%
%  EXAMPLE:
%    a = 2D +time dip_image
%    b = slice_op('gaussf',a,2)
%    same as b = dip_gauss(a,[1 1 0],[2 2 0],[0 0 0])
%
%  See also: ITERATE, IMARFUN

% (C) Copyright 1999-2004               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, Aug 2001
% January 2004 (CL)  Fixed to allow for functions that return data of different
%                    size and/or dimensionality (must be less, though!).

function out = slice_op(oper,in,varargin)

if nargin<2 | ~isa(oper,'char')
   error('Wrong input to SLICE_OP.')
end
sz = size(in);
di = ndims(in);
N = sz(di);
si = substruct('()',[repmat({':'},1,di-1),{0}]);

%set output type
si.subs{end} = 0;
tmp = dip_image(feval(oper,squeeze(subsref(in,si)),varargin{:}));
osz = size(tmp);
sz(1:di-1) = 1;
sz(1:length(osz)) = osz(:);
out = dip_image('zeros',sz,datatype(tmp));
out = subsasgn(out,si,tmp);

for ii = 1:N-1
   si.subs{end} = ii;
   tmp = dip_image(feval(oper,squeeze(subsref(in,si)),varargin{:}));
   out = subsasgn(out,si,tmp);
end
