%SMOOTH   Smoooth all elements of the tensor image.
%    SMOOTH(A,SIGMA) Gaussian blur on all elements of the tensor image.

% (C) Copyright 1999-2000               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, November 2000.
% May, 2003, added recursice gaussian smoothing for large sigmas

function out=smooth(a,sigma)

if nargin < 2
   sigma = 1;
end
if ~isnumeric(sigma)
   error('Sigma parameter must be numeric.')
   % This assures that IN is a dip_image
end
if ~istensor(a)
   error('Image is not a tensor image.');
end

dim = a(1).dims;
sigmas = sigma(:)';
if length(sigmas) == 1
   sigmas = repmat(sigmas,1,dim);
elseif length(sigmas) < dim
   sigmas = repmat(sigma(end),1,dim);
   sigmas(1:length(sigma)) = sigma;
elseif length(sigmas) > dim
   sigmas = sigmas(1:dim);
end
order = repmat(0,1,dim);
process = repmat(1,1,dim);

s = builtin('size',a);
out = dip_image('array',s);
process = ones(size(sigmas));
order = zeros(size(sigmas));
if all(sigmas>7)
   for ii = 1:prod(s)
      out(ii) = gaussf_iir(a(ii),sigmas);
   end
else
   for ii = 1:prod(s)
      out(ii) = dip_gauss(a(ii),process,sigmas,order);
   end
end
