%SUBSREF   Overloaded operator for b=a{i}(j).

% (C) Copyright 1999-2001               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Cris Luengo, July 2000.
% 18 January 2001: Dimensions are preserved.
% 28 March 2001: Added same tests as in SUBSASGN for coordinates.
% 14 August 2001: Fixed bug with trailing singleton dimensions.
% 29 August 2001: Fixed bug when indexing with one index.
% 18 December 2001: Added indexing by 1x1x.. dip_images (BR)
% 15 November 2002: Fixed binary images to work in MATLAB 6.5 (R13)

function b = subsref(a,s)

if ~builtin('isa',a,'dip_image')
   error('Illegal indexing (this shouldn''t happen).')
end
N = length(s);
arrayindex = 0;
imageindex = 0;

for ii=1:N
   if strcmp(s(ii).type,'{}')
      if arrayindex
         error('Illegal indexing.')
      end
      arrayindex = ii;
      idx = s(arrayindex).subs;
      sz = builtin('size',a);
      if length(idx) == 1
         if isnumeric(idx{1}) & (any(idx{1} > prod(sz)) | any(idx{1} < 1))
            error('Index exceeds array dimensions.')
         end
      else
         if length(idx) ~= length(sz)
            error('Number of array indices not the same as image array dimensionality.')
         end
         for ii=1:length(idx)
            if isnumeric(idx{ii}) & (any(idx{ii} > sz(ii)) | any(idx{ii} < 1))
               error('Index exceeds array dimensions.')
            end
         end
      end
   elseif strcmp(s(ii).type,'()')
      if imageindex
         error('Illegal indexing.')
      end
      imageindex = ii;
   else
      error('Indexing not supported on object dip_image.')
   end
   % This assures N <= 2 !!!
end
% First index into array if required.
if arrayindex
   try
      b = builtin('subsref',a,substruct('()',s(arrayindex).subs));
   catch
      error(di_firsterr)
   end
   N = prod(builtin('size',b));
   if N ~= prod(builtin('size',a))
      % Not all components were kept: remove color information.
      for ii=1:N
         b(ii).color = '';
      end
   end
else
   b = a;
   N = prod(builtin('size',b));
end
% Then index into images if required.
if imageindex
   if N > 1
      if ~istensor(b)
         error('Cannot index by pixel in a dip_image_array that is not a tensor.')
      end
   end
   sz = size(b(1).data);
   s = s(imageindex);
   dims = b(1).dims;
   if length(s.subs) == 1 % (this should produce a 1D image)
      if builtin('isa',s.subs{1},'dip_image')
         if ndims(squeeze(s.subs{1}))==0 %added for Piet (BR)
             s.subs{1}=double(s.subs{1})+1;
         elseif ~islogical(s.subs{1})
             error('Only binary images can be used to index.')
         else
             s.subs{1} = logical(s.subs{1}.data);
         end
      elseif ~ischar(s.subs{1}) & ~islogical(s.subs{1})
         s.subs{1} = s.subs{1}+1;
         if any(s.subs{1} > prod(sz)) | any(s.subs{1} < 1)
            error('Index exceeds image dimensions.')
         end
      end
      for ii=1:N
         try
            b(ii).data = builtin('subsref',b(ii).data,s);
            b(ii).data = reshape(b(ii).data,1,prod(size(b(ii).data)));
            b(ii).dims = 1;
         catch
            error(di_firsterr)
         end
      end
   elseif length(s.subs) == b(1).dims
      tmp = s.subs(2);
      s.subs(2) = s.subs(1);
      s.subs(1) = tmp;
      for ii=1:length(sz)
         if islogical(s.subs{ii})
            error('Illegal indexing.')
         elseif builtin('isa',s.subs{ii},'dip_image')
            if ndims(squeeze(s.subs{ii}))==0 %added for Piet (BR)
               s.subs{ii}=double(s.subs{ii});
            else
               error('Illegal indexing.');
            end
         end
         if ~ischar(s.subs{ii})
            s.subs{ii} = s.subs{ii}+1;
            if any(s.subs{ii} > sz(ii)) | any(s.subs{ii} < 1)
               error('Index exceeds image dimensions.')
            end
         end
      end
      for ii=(length(sz)+1):length(s.subs) % indexing into the singleton dimensions
         if builtin('isa',s.subs{ii},'dip_image') | islogical(s.subs{ii})
            error('Illegal indexing.')
         elseif ~ischar(s.subs{ii})
            if any(s.subs{ii} ~= 0)
               error('Index exceeds image dimensions.')
            end
         end
      end
      s.subs = s.subs(1:length(sz));
      for ii=1:N
         try
            b(ii).data = builtin('subsref',b(ii).data,s);
         catch
            error(di_firsterr)
         end
      end
   else
      error('Number of indices not the same as image dimensionality.')
   end
end
