% DIPimage, a scientific image processing toolbox
% Version 1.5.0   29-Jun-2004
%
% Authors: Cris Luengo, Lucas van Vliet, Bernd Rieger
% Project supervisor: Lucas J. van Vliet
% Contact: diplib@ph.tn.tudelft.nl
%
% GUI:
%   dipimage             - Start the DIPimage GUI
%
% File I/O:
%   readim               - Read grey-value image from file
%   readcolorim          - Read color image from file
%   readroiim            - Read ROI of a grey-value image from file
%   readtimeseries       - Reads a series of images from disk in one image.
%   writeim              - Write grey-value or color image to file
%   readavi              - Reads AVI movie into a 3D image
%   writeavi             - Writes 3D image into an AVI file
%   writedisplayavi      - Writes 3D image into an AVI file
%
% Display:
%   overlay              - Overlay a grey-value or color image with a binary image
%   overlay_label        - Overlay a grey-value image with a label image
%   overlay_confidence   - Overlay a grey-value image with a grey-value image
%   overlay_vector       - Overlay a grey-value image with a vector image
%   orientationplot      - Plot 2/3D orientation
%   dipgetimage          - Retrieves an image from a display
%   dipcrop              - Interactive image cropping
%   dipgetcoords         - Interactive coordinate extraction
%   diproi               - Interactive ROI selection
%   diptruesize          - Sets the size of a display to its natural size
%   dipclf               - Clears figure windows created by DIPSHOW
%
% Generation:
%   newim                - Creates a dip_image of the specified size
%   deltaim              - Generate a discrete delta function
%   ramp                 - Creates an image with general coordinates.
%   xx                   - Creates an image with X coordinates
%   yy                   - Creates an image with Y coordinates
%   zz                   - Creates an image with Z coordinates
%   rr                   - Creates an image with R coordinates
%   phiphi               - Creates an image with Phi coordinates
%   testobject           - Creates bandlimited test objects
%   noise                - Add noise to an image
%   drawline             - Draws a line in an image
%   drawpolygon          - Draws a polygon
%   gaussianblob         - Adds a Gauss shaped spot to an  image
%
% Manipulation:
%   shift                - Shift an image
%   rotation             - Rotate a 2D/3D image around an axis
%   rotation3d           - Rotate a 3D image
%   mirror               - Mirror an image
%   resample             - Resample an image
%   subsample            - Subsample an image
%
% Point:
%   clip                 - Grey-value clipping
%   erfclip              - Grey-value error function clipping
%   gaussianedgeclip     - Clips/maps grey-values to produce a Gaussian edge
%   gaussianlineclip     - Clips/maps grey-values to produce a Gaussian line
%   stretch              - Grey-value stretching
%   hist_equalize        - Histogram equalization
%   threshold            - Thresholding
%   lut                  - Look-up Table (with interpolation)
%   get_subpixel         - Retrieves subpixel values in an image
%
% Filters:
%   convolve             - General convolution filter
%   gaussf               - Gaussian filter
%   gaussf_iir           - Gaussian filter (IIR version)
%   unif                 - Uniform filter
%   maxf                 - Maximum filter
%   minf                 - Minimum filter
%   medif                - Median filter
%   percf                - Percentile filter
%   varif                - Variance filter
%   gabor                - Gabor filter
%   gabor_click          - Gabor filter
%   canny                - Canny edge detector
%
% Differential Filters:
%   gauss_derivative     - Gaussian derivatives
%   gauss_fourier        - Computes (higher order) Gaussian derivatives in Fourier domain.
%   dx                   - First Gaussian derivative in the X-direction
%   dy                   - First Gaussian derivative in the Y-direction
%   dz                   - First Gaussian derivative in the Z-direction
%   gradmag              - Gradient magnitude
%   gradientvector       - Gradient vector of an image.
%   dxx                  - Second Gaussian derivative in the X-direction
%   dyy                  - Second Gaussian derivative in the Y-direction
%   dzz                  - Second Gaussian derivative in the Z-direction
%   dxy                  - Second Gaussian derivative in the XY-direction
%   dxz                  - Second Gaussian derivative in the XZ-direction
%   dyz                  - Second Gaussian derivative in the YZ-direction
%   dgg                  - Second Gaussian derivative in the gradient-direction
%   dcc                  - Second Gaussian derivative in the contour-direction
%   laplace              - Laplace operator
%   laplace_plus_dgg     - Laplace + Dgg
%   laplace_min_dgg      - Laplace - Dgg
%   hessian              - Hessian matrix of an image
%
% Adaptive Filters:
%   kuwahara             - Kuwahara filter for edge-preserving smoothing
%   selectionf           - Selection filter
%   tframehessian        - Second derivatives driven by structure tensor
%   pmd                  - Perona Malik anisotropic diffusion
%   aniso                - Robust Anisotropic Diffusion using Tukey error norm
%   mcd                  - Mean Curvature Diffusion
%   cpf                  - Nonlinear Diffusion using Corner Preserving Formula (improved over MCD)
%   ced                  - Coherence Enhancing (anisotropic) Diffusion
%   gaussf_adap          - Adaptive Gaussian Filtering.
%   percf_adap           - Adaptive Percentile Filtering.
%   gaussf_adap_banana   - Adaptive Gaussian Filtering in banana like neighborhood
%   percf_adap_banana    - Adaptive Percentile Filtering in banana like neighborhood
%   bilateralf           - Bilateral filter with different implementations
%
% Binary Filters:
%   bdilation            - Binary dilation
%   berosion             - Binary erosion
%   bopening             - Binary opening
%   bclosing             - Binary closing
%   hitmiss              - Hit-Miss operator
%   bskeleton            - Binary skeleton
%   bpropagation         - Binary propagation
%   brmedgeobjs          - Remove edge objects from binary image
%   hull                 - Generates convex hull of a binary image
%   countneighbours      - Counts the number of neighbours each pixel has
%   bmajority            - Binary majority voting
%   getsinglepixel       - Get single-pixels from skeleton
%   getendpixel          - Get end-pixels from skeleton
%   getlinkpixel         - Get link-pixels from skeleton
%   getbranchpixel       - Get branch-pixels from skeleton
%
% Morphology:
%   dilation             - Grey-value dilation
%   erosion              - Grey-value erosion
%   closing              - Grey-value closing
%   opening              - Grey-value opening
%   tophat               - Top hat
%   dilation_se          - Grey-value dilation with a user-defined structuring element
%   erosion_se           - Grey-value erosion with a user-defined structuring element
%   closing_se           - Grey-value closing with a user-defined structuring element
%   opening_se           - Grey-value opening with a user-defined structuring element
%   rankmin_closing      - Rank-min closing
%   rankmax_opening      - Rank-max opening
%   rankmin_closing_se   - Rank-min closing with user defined structuring element
%   rankmax_opening_se   - Rank-max opening with user defined structuring element
%   reconstruction       - Morphological reconstruction by dilation
%   watershed            - Watershed
%
% Transforms:
%   ft                   - Fourier Transform (forward)
%   ift                  - Fourier Transform (inverse)
%   ht                   - Hilbert Transform for nD images
%   dt                   - Euclidean Distance Transform
%   vdt                  - Vector Distance Transform
%   gdt                  - Grey-Weighted Distance Transform
%   label                - Label objects in a binary image
%
% Analysis:
%   measure              - Do measurements on objects in an image
%   msr2obj              - Label each object in the image with its measurement
%   msr2ds               - Convert a measurement structure to a PRTOOLS dataset
%   measurehelp          - Provides help on the measurement features
%   scalespace           - Gaussian scale-space
%   morphscales          - Morphological scale-space
%   scale2rgb            - Convert scale-space to RGB image
%   structuretensor      - Computes Structure Tensor on 2D images
%   structuretensor3d    - Computes Structure Tensor on 3D images
%   curvature            - Curvature in grey value images in nD
%   pst                  - Parametric Structure Tensor
%   granulometry         - Obtains a (dark) particle size distribution.
%   opticflow            - Computes the optic flow of a 2D/3D time series
%   findshift            - Finds shift between two images
%   findlocmax           - Finds iteratively the local maximum in
%   backgroundoffset     - Remove  background offset
%   splitandmerge        - Split and Merge clustering algorithm
%
% Statistics:
%   diphist              - Displays a histogram
%   mdhistogram          - Compute a Multi-dimensional histogram
%   chordlength          - Computes the chord lengths of the phases in a labeled image
%   paircorrelation      - Computes the pair correlation of the phases in a labeled image
%   radialsum            - Computes the sum as a function of the R-coordinate
%   radialmean           - Computes the average as a function of the R-coordinate
%   radialmin            - Computes the minimum as a function of the R-coordinate
%   radialmax            - Computes the maximum as a function of the R-coordinate
%   mse                  - Mean square error
%   mre                  - Mean relative error
%
%
% Other available functions are:
%   acquireim            - Read image from a TWAIN source
%   arcf                 - Arc-shape filter (1d oriented & curved Gaussian/bilateral filter)
%   arrangeslices        - Converts an n-D image into a 2D image by arringing the slices
%   array2im             - Convert a dip_image_array to an image stack
%   curvature_thirion    - Isophote curvature in grey value images
%   deblock              - Remove blocking artifact from JPEG compressed images
%   dip_image_array      - Creates an array of empty dip_images
%   dip_image_new        - Creates a dip_image of the specified size
%   dip_morph_flavour    - Sets or gets the morphological flavour
%   dipanimate           - Animates a 3D image in a display window
%   dipfig               - Links a variable name with a figure window
%   dipgetpref           - Gets a DIPimage preference
%   dipinit              - Initialize the working environment
%   dipisosurface        - plot isosurfaces of 3D grey value images
%   diplink              - Linking of displays for 3D images
%   diplooking           - Interactive looking glas over the image
%   dipmapping           - Changes the mapping of an image in a figure window
%   dipmenus             - Not a user function
%   diporien             - Interactive orientation testing
%   dippan               - Interactive panning of an image
%   dipprofile           - Interactive extraction of 1D function from image
%   dipsetpref           - Sets a DIPimage preference
%   dipshow              - Shows a dip_image object as an image
%   dipstep              - Stepping through slices of a 3D image
%   diptest              - Interactive pixel testing
%   dipzoom              - Interactive image zooming
%   findospeaks          - Find peaks in Orientation Space
%   getparams            - Automated parameter parsing for DIPimage functions.
%   hybridf              - Denoise by a soft blending of arc filter and Gaussian filter
%   im2array             - Convert an image stack to a dip_image_array
%   isophote_curvature   - Isophote curvature in grey value images
%   jacobi               - Symmetric eigenvalue analysis
%   joinchannels         - Joins scalar images as channels in a color image
%   make_gamut           - Make the gamut for given device and measured values.
%   measure_gamma_monitor - Interactive tool to measure the gamma of your monitor
%   monitor_icc          - Converts the colors of an image according to the given ICC profile
%   nconv                - Normalized Convolution
%   newimar              - Creates an array of empty dip_images
%   noisestd             - Estimate noise standard deviation
%   orientation4d        - Orientation estimation in 4D
%   orientationspace     - Orientation Space
%   plot_gamut           - The intersection of a gamut boundary with a constant hue plane
%   printer_icc          - Converts the colors of an image according to the given ICC profile
%   psnr                 - Peak Signal-to-Noise Ratio in dB
%   read_icc_profile     - Read the values on an ICC header
%   scanner_icc          - Converts the colors of an image according to the given ICC profile
%   spectra2xyz          - Converts input spectra to XYZ values
%   structf              - Structure adaptive filter (oriented, variable-sized Gaussian filtering)
%   view5d               - Start the java viewer by Rainer Heintzmann
%   write_icc_profile    - Make a ICC profile
%
% Type
%   methods dip_image
% to get a list of functions overloaded for dip_images.
%
% More information about DIPimage is available in the on-line manual:
%   http://www.ph.tn.tudelft.nl/DIPlib/docs/dipimage_user_manual.pdf

% (C) Copyright 1999-2004               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
