%BCLOSING   Binary closing
%
% SYNOPSIS:
%  image_out = bclosing(image_in,iterations,connectivity,edgeCondition)
%
% PARAMETERS:
%  iterations: the number of steps taken, defines the size of the
%     structuring element.
%  connectivity: defines the metric, that is, the shape of the structuring
%     element.
%     * 1 indicates city-block metric, or a diamond-shaped S.E.
%     * 2 indicates chessboard metric, or a square structuring element.
%     * -1 indicates alternating connectivity: first 1, then 2, then 1
%     again, etc. -2 is the same but starting with 2. These produce an
%     octagonal structuring element.
%     Connectivity can never be larger than the image dimensionality.
%  edgeCondition: defines the value of the pixels outside the image. It
%     can be 0 or 1.
%
% DEFAULTS:
%  iterations = 1
%  connectivity = -2 (1 in 3D)
%  edgeCondition = 1

% (C) Copyright 1999-2001               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Lucas van Vliet, May 2000.

function image_out = bclosing(varargin)

d = struct('menu','Binary Filters',...
           'display','Binary closing',...
           'inparams',struct('name',       {'image_in',   'iterations','connectivity','edgeCondition'},...
                             'description',{'Input image','Iterations','Connectivity','Edge Condition'},...
                             'type',       {'image',      'array',     'array',       'option'},...
                             'dim_check',  {0,            0,           0,             0},...
                             'range_check',{[],           'N+',        [-2 Inf],      {0,1}},...
                             'required',   {1,            0,           0,             0},...
                             'default',    {'a',          1,           -2,            1}...
                              ),...
           'outparams',struct('name',{'image_out'},...
                              'description',{'Output image'},...
                              'type',{'image'}...
                              )...
           );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      image_out = d;
      return
   end
end
try
   [image_in,iterations,connectivity,edgeCondition] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end

if ndims(image_in) == 3 & connectivity < 1
   connectivity = 1;
end

image_out = dip_binaryclosing(image_in,connectivity,iterations,edgeCondition);
