%DRAWLINE   Draws a line in an image
%
% SYNOPSIS:
%  image_out = drawline(image_in, start, end, intensity)
%
%  start:     array containing the start position of the line
%  end:       array containing the end position of the line
%  intensity: intensity of the line
%
% DEFAULTS:
%  intensity = 255;

% (C) Copyright 1999-2001               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, Apr 2001

function out = drawline(varargin)

d = struct('menu','Generation',...
           'display','Add line',...
           'inparams',struct('name',       {'in',         'st',    'ed',      'inten'},...
                             'description',{'Input image','Start Coordinates','End Coordinates','Intensity'},...
                             'type',       {'image',      'array',    'array',     'array',},...
                             'dim_check',  {0,            1,           1,           0, },...
                             'range_check',{[],           'R+',        'R+',         'R'},...
                             'required',   {1,            1,           1,           0},...
                             'default',    {'a',          '[0 0]',  '[255 255]',           255}...
                            ),...
           'outparams',struct('name',{'out'},...
                              'description',{'Output image'},...
                              'type',{'image'}...
                              )...
         );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      out = d;
      return
   end
end
try
   [in,st,ed,inten] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end

out = dip_drawline(in, st, ed, inten);
