%DRAWPOLYGON   Draws a polygon
%
% SYNOPSIS:
%    out = drawpolygon(in,coordinates,colour,closed);
%
% PARAMETERS:
%    coordinates: matrix containing the coordinates of the corner points
%       of the polygon. It is organised as follows:
%       coordinates=[x1 y1 z1; x2 y2 z2; etc...]
%    colour: gray value with which to draw the lines
%    closed: 'open': do not connect the last point to the first point
%            'closed': do connect the last point to the first point,
%
% DEFAULTS:
%    closed = 'open'

% (C) Copyright 1999-2000               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Michael van Ginkel, December 2000.

function oim = drawpolygon(iim,cor,colour,closed)

% Avoid being in menu
if nargin == 1
   if ischar(iim) & strcmp(iim,'DIP_GetParamList')
      oim = struct('menu','none');
      return
   end
end

closepolygon = 0;
if nargin == 4
   switch closed
      case 'open'
      case 'closed'
         closepolygon = 1;
      otherwise
         error('fourth parameter must be ''open'' or ''closed''');
   end
end

noofnodes = size(cor,1);
if noofnodes == 1
   error('number of points must be > 1');
end
oim = iim;
for ii=1:(noofnodes-1)
   oim = dip_drawline( oim, cor(ii,:), cor(ii+1,:), colour );
end
if closepolygon == 1
   oim = dip_drawline( oim, cor(noofnodes,:), cor(1,:), colour );
end
