%FINDLOCMAX   Finds iteratively the local maximum in 
%             a LSIZE cube.
%
% SYNOPSIS:
%   out = findlocmax(in, cood, lsize)
%
% PARAMETERS:
%   in:    input image
%   cood:  starting coordinates
%   lsize: cube size = 2*floor(lsize./2)+1
%
% EXAMPLES:
%   out = findlocmax(readim,[20 160],[15 15])

% (C) Copyright 1999-2004               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, 2004
 
function out = findlocmax(varargin)


d = struct('menu','Analysis',...
        'display','Find local maximum',...
        'inparams',struct('name',{'in','cood','lsize'},...
   'description',{'Input image','Start coordinate','Size of the cube'},...
   'type',              {'image','array','array'},...
   'dim_check',  {0,1,1},...
   'range_check',{[],'N','N'},...
   'required',  {1,1,1},...
   'default',   {'a',[128 128],10}...
        ),...
   'outparams',struct('name',{'out'},...
          'description',{'Output'},...
          'type',{'image'}...
          )...
 );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      out = d;
      return
   end
end
try
   [in,cood,lsize] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end

N=ndims(in);
s = floor(lsize./2);
%2s+1 neighborhood
co = zeros(N,2);%corner array
ss = 'roi=in(';%make roi coordinate array
ts = 'tmpv = in(';
for ii=1:N
   ss = [ss 'co(' num2str(ii) ',1):co(' num2str(ii) ',2),'];
   ts = [ts 'cood(' num2str(ii) '),']; 
end
ss(end)=[];ts(end)=[];
ss = [ ss ');'];ts=[ts ');'];

done =0;
while ~done
   for ii=1:N  
      co(ii,1) = max(min(cood(ii)-s(ii),size(in,ii)-1),0);
      co(ii,2) = max(min(cood(ii)+s(ii),size(in,ii)-1),0);          
   end  
   eval(ss);        %get roi
   v = max(roi);    %get max value in roi
   eval(ts);        %get value of prior max
   if v == tmpv
      out = cood;
      done = 1;
   else
      nc = findcoord(roi==v);
      nc = nc(1,:);%just in case we find more than one max
      cood = cood - s;
      cood(cood<0)=0;
      cood = cood + nc;
   end
end
