%FINDSHIFT  Finds shift between two images
%
% SYNOPSIS:
%  shiftvector = findshift(in1, in2, method, parameter)
%
% PARAMETERS:
%  method = 'integer': find integer shift only (nD)
%           'ffts'   : normalized cross-correlation (2D only)
%           'grs'    : gradient based (first order Taylor, 1D-3D)
%           Both 'ffts' and 'grs' first correct for the integer shift.
%  para = scalar paramter:
%           for 'integer': ignored
%           for 'ffts'   : Sets the amount of frequencies used in this estimation.
%                          The maximum value that makes sense is sqrt(1/2). Choose
%                          smaller values to ignore more high frequencies. The
%                          default value is 0.2.
%           for 'grs'    : Sigma for the Gaussian smoothing. Defaults to 1.
%
% DEFAULTS:
%  method = 'integer'
%  parameter = 0 (meaning use the default value for the method)
%
% LITERATURE:
%  C.L. Luengo Hendriks, Improved Resolution in Infrared Imaging Using
%    Randomly Shifted Images, M.Sc. Thesis, Delft University of Technology, 1998

% (C) Copyright 1999-2004               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, March 2002.
% 16 April 2004: added some comments to the help. (CL)

function out = findshift(varargin)

d = struct('menu','Analysis',...
  'display','Find shift',...
  'inparams',struct('name',{'in1', 'in2',  'method','para'},...
       'description',{'Input image 1','Input image 2','Method','Paramter'},...
       'type',       {'image','image','option', 'array'},...
       'dim_check',  {0,0,0,0},...
       'range_check',{[],[],{'integer','ffts','grs'},'R+'},...
       'required',   {1,1,0,0},...
       'default',    {'a', 'b','integer',0}...
      ),...
  'outparams',struct('name',{'out'},...
      'description',{'Shift'},...
      'type',{'array'}...
      )...
 );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      out = d;
      return
   end
end
try
   [in1,in2, method, para] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end
out = dip_findshift(in1,in2,method,para);
