%GAUSS_DERIVATIVE   Gaussian derivatives
%
% SYNOPSIS:
%  image_out = gauss_derivative(image_in,sigma,order)
%
% PARAMETERS:
%  sigma = smoothing for the different directions
%          0: direction not processed
%
% DEFAULTS:
%  sigma = 1
%  order = 1
%
% EXAMPLE:
%  a = readim;
%  gauss_derivative(a,1,0) - gaussf(a,1)
%  gauss_derivative(a,[1 0],[1 1]) - dx(a,1)
%  gauss_derivative(a,[1 1],[1 0]) - dx(a,1)

% (C) Copyright 1999-2000               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Lucas van Vliet, May 2000.
% april 2004: kees van wijk
%   derivative of higher orders are now computed in the fourier domain!


function image_out = gauss_derivative(varargin)

d = struct('menu','Differential Filters',...
           'display','General Gaussian derivatives',...
           'inparams',struct('name',       {'image_in',   'sigma',            'order'},...
                             'description',{'Input image','Sigma of gaussian','Derivative Order'},...
                             'type',       {'image',      'array',            'array'},...
                             'dim_check',  {0,            1,                  1},...
                             'range_check',{[],           'R+',               'N'},...
                             'required',   {1,            0,                  0},...
                             'default',    {'a',          1,                  1}...
                            ),...
           'outparams',struct('name',{'image_out'},...
                              'description',{'Output image'},...
                              'type',{'image'}...
                              )...
          );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      image_out = d;
      return
   end
end
try
   [image_in,sigma,order] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end
process = ones(size(sigma));

% dip_gauss works up to second derivative only!
if any(order)>2 
  image_out = gauss_fourier( image_in, sigma, order );
else
  image_out = dip_gauss(image_in,process,sigma,order); 
end


