%GAUSS_FOURIER   Computes (higher order) Gaussian derivatives in Fourier domain.
%
% SYNOPSIS:
%  image_out = gauss_fourier( image_in, [sigmas], [derivative order] );
%
%  image_in           - nD input image
%  [sigmas]           - array of scales
%  [derivative order] - order of derivative in each dimension
%                       [ 0 3 0 ] means take 3th derivative along
%                       second dimension
%
% EXAMPLES:
%  out = gauss_fourier( readim,  [2,2], [1 1] ); % equals dxy(readim,2);
%  out = gauss_fourier( xx(50,50,50), [3,2,4], [1 0 0] );

% (C) Copyright 1999-2004               Quantitative Imaging Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Kees van Wijk, April 2004.

function image_out = gauss_fourier( varargin )

d = struct('menu','Differential Filters',...
           'display','General Gaussian derivatives in Fourier Domain',...
           'inparams',struct('name',       {'image_in',   'sigma',            'order'},...
                             'description',{'Input image','Sigma of gaussian','Derivative Order'},...
                             'type',       {'image',      'array',            'array'},...
                             'dim_check',  {0,            1,                  1},...
                             'range_check',{[],           'R+',               'N'},...
                             'required',   {1,            0,                  0},...
                             'default',    {'a',          1,                  1}...
                            ),...
           'outparams',struct('name',{'image_out'},...
                              'description',{'Output image'},...
                              'type',{'image'}...
                              )...
          );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      image_out = d;
      return
   end
end
try
   [image_in,sigma,order] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end

dims = ndims(image_in);

inft = ft(image_in);
for ii=1:dims
   t = createramp(size(image_in),ii,'freq');
   inft = inft .* ( (i*2*pi) * t ).^order(ii) .* exp( -0.5 * ( (2*pi*sigma(ii)) * t ).^2 );
end
image_out = real( ift( inft ));
 