%GAUSSF_IIR   Gaussian filter (IIR version)
%
% SYNOPSIS:
%  image_out = gaussf_iir(image_in,sigma)
%
% DEFAULTS:
%  sigma = 1

% (C) Copyright 1999-2002               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Michael van Ginkel, Sep 2002.

function image_out = gaussf_iir(varargin)

if nargin==0
   if exist('private/Gauss.jpg','file')
      image_out = dip_image(imread('private/Gauss.jpg'));
      return
   end
end

d = struct('menu','Filters',...
           'display','Gaussian filter (IIR implementation)',...
           'inparams',struct('name',       {'image_in',   'sigma'},...
                             'description',{'Input image','Sigma of gaussian'},...
                             'type',       {'image',      'array'},...
                             'dim_check',  {0,            1},...
                             'range_check',{[],           'R+'},...
                             'required',   {1,            0},...
                             'default',    {'a',          1}...
                            ),...
           'outparams',struct('name',{'image_out'},...
                              'description',{'Output image'},...
                              'type',{'image'}...
                              )...
          );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      image_out = d;
      return
   end
end
try
   [image_in,sigma] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end
process = ones(size(sigma));
order = zeros(size(sigma));
filterorder = 3*ones(size(sigma));

% default design method: discrete time fit
% 1=forward backward method
% 2=discrete time fit
image_out = dip_gaussiir(image_in,process,sigma,order,filterorder,2);
