%GRADIENTVECTOR   Gradient vector of an image.
%   GRADIENTVECTOR(A,SIGMA) returns the gradient vector of a real valued,
%   scalar image. SIGMA is the Gaussian smoothing. The returned type
%   is an N-by-1 image array, where N is the dimensionality of A.

% (C) Copyright 1999-2000               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, August 2000.
% Cris Luengo, 21 September 2000: SIGMA is now allowed to be any size vector.

function out = gradientvector(varargin)

d = struct('menu','Differential Filters',...
           'display','Gradient vector',...
           'inparams',struct('name',       {'in',         'sigma'},...
                             'description',{'Input image','Sigma of gaussian'},...
                             'type',       {'image',      'array'},...
                             'dim_check',  {0,            1},...
                             'range_check',{[],           'R+'},...
                             'required',   {1,            0},...
                             'default',    {'a',          1}...
                            ),...
           'outparams',struct('name',{'out'},...
                              'description',{'Output image'},...
                              'type',{'image'}...
                              )...
          );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      out = d;
      return
   end
end
try
   [in,sigma] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end

if ~isreal(in)
   error('Input image must be real.')
end

out = gradient(in,sigma);
