%GRADMAG   Gradient magnitude
%
% SYNOPSIS:
%  image_out = gradmag(image_in,sigma)
%
% DEFAULTS:
%  sigma = 1

% (C) Copyright 1999-2000               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Lucas van Vliet, May 2000.

function image_out = gradmag(varargin)

d = struct('menu','Differential Filters',...
           'display','Gradient magnitude',...
           'inparams',struct('name',       {'image_in',   'sigma'},...
                             'description',{'Input image','Sigma of gaussian'},...
                             'type',       {'image',      'array'},...
                             'dim_check',  {0,            1},...
                             'range_check',{[],           'R+'},...
                             'required',   {1,            0},...
                             'default',    {'a',          1}...
                            ),...
           'outparams',struct('name',{'image_out'},...
                              'description',{'Output image'},...
                              'type',{'image'}...
                              )...
          );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      image_out = d;
      return
   end
end
try
   [image_in,sigma] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end

process = ones(size(sigma));
image_out = dip_gradientmagnitude(image_in,process,sigma,'firgauss');

%if ndims(image_in) >= 1
%   image_out = dx(image_in, sigma)^2;
%end
%if ndims(image_in) >= 2
%   image_out = image_out + dy(image_in, sigma)^2;
%end
%if ndims(image_in) >= 3
%   image_out = image_out + dz(image_in, sigma)^2;
%end
%
%image_out = image_out^(0.5);
