%MEASURE_GAMMA_MONITOR   Interactive tool to measure the gamma of your monitor
%
% SYNOPSIS:
%  gamma_RGB = measure_gamma_monitor(gamma_ramp, figure_position)


% (C) Copyright 1999-2001               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Judith Dijk.

function gamma_RGB = measure_gamma_monitor(gamma_ramp, figure_position)
   if nargin == 1 & ischar(gamma_ramp) & strcmp(gamma_ramp,'DIP_GetParamList') % Avoid being in menu
      gamma_RGB = struct('menu','none');
      return
   end	
   if( nargin <2)
		figure_position = [100 100 1000 700]; % in pixels
	end
   if( nargin <1)
		gamma_ramp = 2;
	end
   
  global fig axes1 axes2 axes3 slider1 slider2 slider3;
  global submit submitted;
	
% Data for GUI element placement.

  mat1 = ...
  [        0         0    1.0000; ...
           0    0.5000         0; ...
      1.0000         0         0; ... 
           0    0.7500    0.7500; ...
      0.7500         0    0.7500; ...
      0.7500    0.7500         0; ...
      0.2500    0.2500    0.2500 ];
  mat2 = [ 0.4980    1.0204    9.1603 ];
  mat3 = mat1;
  mat4 = [-1.3092    1.1020    9.1603 ];
  mat5 = mat2;

  h0 = figure('Color',[0.5 0.5 0.5], ...
    'FileName','measure_gamma_monitor.m', ...
    'PaperPosition',[18 180 576 432], ...
    'PaperUnits','points', ...
    'Position',figure_position, ...
    'Tag','Fig1', ...
    'ToolBar','none', ...
    'Resize', 'off');
  fig = h0;
  
  h1 = axes('Parent',h0, ...
    'CameraUpVector',[0 1 0], ...
    'Color',[1 1 1], ...
    'ColorOrder',mat1, ...%    
    'Position', [0.1 0.75 0.5 0.2], ...
    'Tag','Axes1', ...
    'XColor',[0 0 0], ...
    'XTickMode','manual', ...
    'YColor',[0 0 0], ...
    'YTickMode','manual', ...
    'ZColor',[0 0 0]);
  axes1 = h1;
  h1 = axes('Parent',h0, ...
    'CameraUpVector',[0 1 0], ...
    'Color',[1 1 1], ...
    'ColorOrder',mat1, ...
    'Position', [0.1 0.45 0.5 0.2], ...
    'Tag','Axes2', ...
    'XColor',[0 0 0], ...
    'XTickMode','manual', ...
    'YColor',[0 0 0], ...
    'YTickMode','manual', ...
    'ZColor',[0 0 0]);
  axes2 = h1;
  h1 = axes('Parent',h0, ...
    'CameraUpVector',[0 1 0], ...
    'Color',[1 1 1], ...
    'ColorOrder',mat1, ...
    'Position', [0.1 0.15 0.5 0.2], ...
   'Tag','Axes3', ...
    'XColor',[0 0 0], ...
    'XTickMode','manual', ...
    'YColor',[0 0 0], ...
    'YTickMode','manual', ...
    'ZColor',[0 0 0]);
  axes3 = h1;

  h1 = uicontrol('Parent',h0, ...
    'Units','normalized', ...
    'BackgroundColor',[0.701960784313725 0.701960784313725 ...
    	0.701960784313725], ...
    'ListboxTop',0, ...
    'Position', [0.65 0.85 0.32 0.035], ...
    'Style','slider', ...
    'Tag','Slider1');
  slider1=h1;
  h1 = uicontrol('Parent',h0, ...
    'Units','normalized', ...
    'BackgroundColor',[0.701960784313725 0.701960784313725 ...
    	0.701960784313725], ...
    'ListboxTop',0, ...
    'Position',[0.65 0.55 0.32 0.035], ...
    'Style','slider', ...
    'Tag','Slider2');
  slider2=h1;
  h1 = uicontrol('Parent',h0, ...
    'Units','normalized', ...
    'BackgroundColor',[0.701960784313725 0.701960784313725 ...
    	0.701960784313725], ...
    'ListboxTop',0, ...
    'Position',[0.65 0.25 0.32 0.035], ...
    'Style','slider', ...
    'Tag','Slider3');
  slider3=h1;
  h1 = uicontrol('Parent',h0, ...
    'Units','points', ...
    'BackgroundColor',[0.701960784313725 0.701960784313725 ...
    	0.701960784313725], ...
    'FontSize',18, ...
    'FontWeight','bold', ...
    'ListboxTop',0, ...
    'Position',[0 0 144, 48], ...
    'String','SUBMIT', ...
    'CallBack','submit_callback', ...
    'Tag','Pushbutton1');
  submit=h1;

  set (gcf, 'MenuBar', 'no');
	
  % Set slider to halfway (no preference).

  set (slider1, 'Value', [ 0.5 ]);
  set (slider2, 'Value', [ 0.5 ]);
  set (slider3, 'Value', [ 0.5 ]);
 
   % noise ramp, keeps constant. first make noise, add a ramp and clip

   gamma_monitor = 2;
   gamma_exp = 1./gamma_monitor;
   tmp = noise(xx*0,'uniform',0,255);
   qr=255*((128+xx)/255).^gamma_ramp;
   tmp=tmp+qr;
   tmp=255*threshold(tmp,'fixed',Inf);
   
  
   imageR = zeros(256, 256, 3);
   imageR(1:128, :, 1) = double( tmp(:, 0:127));
   imageG = zeros(256, 256, 3);
   imageG(1:128, :, 2) = double( tmp(:, 0:127));
   imageB = zeros(256, 256, 3);
   imageB(1:128, :, 3) = double( tmp(:, 0:127));
   
   xx_in = double((128+xx)./255).^gamma_ramp;
   xx_in = xx_in(1:128, :);
   
%   tmp(:,128:255)=qr(:,128:255);
%   out1=dip_image_array(tmp,tmp*0,tmp*0);
%   out2=dip_image_array(tmp*0,tmp,tmp*0);
%   out3=dip_image_array(tmp*0,tmp*0,tmp);
%   out1=colorspace(out1,'RGB');
%   out2=colorspace(out2,'RGB');
%   out3=colorspace(out3,'RGB');

   % note that the gammavalues range from 0-4, the start value is 2.
   
   submitted = 0;
   while (~submitted)     
      pause (3);
		gammaR = get(slider1, 'Value').*(2.*gamma_exp); 
 		gammaG = get(slider2, 'Value').*(2.*gamma_exp);
      gammaB = get(slider3, 'Value').*(2.*gamma_exp);
      imageR(129:256, :, 1) = (xx_in.^gammaR).*255;
      imageG(129:256, :, 2) = (xx_in.^gammaG).*255;
      imageB(129:256, :, 3) = (xx_in.^gammaB).*255;
      fprintf(1, '%f %f %f\n', gammaR, gammaG, gammaB);
      axes (axes1); imagesc (uint8(imageR)); axis off; 
      axes (axes2); imagesc (uint8(imageG)); axis off; 
      axes (axes3); imagesc (uint8(imageB)); axis off; 
   end;

   
	 % And find the gamma value.

    gamma_RGB(1 ) = get (slider1, 'Value').*(2.*gamma_exp);
    gamma_RGB(2 ) = get (slider2, 'Value').*(2.*gamma_exp);
    gamma_RGB(3 ) = get (slider3, 'Value').*(2.*gamma_exp);
  % Remove callback functions and close figure.

  set (submit, 'CallBack', '');
  set (gcf, 'ResizeFcn', '');
  close (fig);
  
return

% SUBMIT_CALLBACK
%
% Called whenever the user presses 'SUBMIT'.

function submit_callback

  global fig axes1 axes2 axes3 slider submit submitted;

  submitted = 1;

return 


