%MSR2OBJ   Label each object in the image with its measurement
%
% SYNOPSIS:
%  image_out = msr2obj(image_in,msr,measurementID)
%
% PARAMETERS:
%  msr: measurement structure.
%  measurementID: name of one of the measurements in msr.
%                 If empty, the first one is taken.

% (C) Copyright 1999-2002               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Cris Luengo, November 2000.
% February 2002:  Using the new function 'dip_getmeasurefeatures' - removed static lists.
% Sep 2002: Keep datatype of measurement for output images (BR)

function image_out = label(varargin)

msmts = [struct('name','','description',''),dip_getmeasurefeatures];

d = struct('menu','Analysis',...
   'display','Convert labels to measurements',...
   'inparams',struct('name',       {'image_in',   'msr',             'msrID'},...
      'description',{'Label image','Measurement Data','Measurement ID'},...
      'type',       {'image',      'measurement',     'option'},...
      'dim_check',  {0,            0,                 0},...
      'range_check',{[],           [],                {msmts.name}},...
      'required',   {1,            1,                 0},...
      'default',    {'a',          '',                msmts(1).name}...
     ),...
   'outparams',struct('name',{'image_out'},...
                      'description',{'Output image'},...
                      'type',{'image'}...
                      )...
  );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      image_out = d;
      return
   end
end
try
   [image_in,msr,msrID] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end

type = class(dip_array(image_in));
if ~strncmp(type,'int',3) & ~strncmp(type,'uint',4)
   error('Integer input image expected.')
end
if isempty(msrID)
   msrID = fieldnames(msr);
   msrID = msrID{1};
end
newlabs = eval(['msr.',msrID],'error(lasterr)');
table = zeros(max(image_in),1);
table(msr.id) = newlabs(1,:);
table = feval(class(newlabs),[0;table]);
%keep datatype of the labels, save memory

image_out = lut(image_in,table);
