%ORIENTATIONPLOT   Plot 2/3D orientation
%
% SYNOPSIS:
%   orientationplot(in1, in2, mask, subsample, scale, arrow)
%
% PARAMETERS:
%  in1: dip_image_array containing the vector 2/3D
%      or the angle phi 2/3D
%  in2: angle theta 3D
%  mask: mask image
%  subsample: array containing the subsampling factors
%  scale: scale of the lines ploted
%  arrow: 'none','arrow'
%
% DEFAULTS:
%  subsampling: 8
%  scale: 0.5
%  arrow: 'none'

% (C) Copyright 1999-2001               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, Aug 2001.
% Corrected fliped axis, matlab <-> dipimage, March 2002 (BR)
% Small bug fix, March 2002 (CL+BR)

function out = orientationplot(varargin)

d = struct('menu','Display',...
   'display','Orientationplot',...
   'inparams',struct('name',       {'in1','in2','mask','value','scale','arr'},...
    'description',{'Orientaion input 1','Orientaion input 1','Mask Image','Subsampling','Scaling','Arrow'},...
    'type',       {'image','image','image','array', 'array','option'},...
    'dim_check',  {0,0,0,0,0,0},...
    'range_check',{[],[],[],'R+','R+',{'none','arrow'}},...
    'required',   {1,0,0,0,0,0},...
    'default',    {'','','threshold(a)',8,0.5,'none'}...
   ),...
   'outparams',struct('name',{'out'},...
                      'description',{'Line handles'},...
                      'type',{'handle'}...
                      )...
  );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      out = d;
      return
   end
end
try
   [in1,in2,mask,value,scale,arr] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end
if isvector(in1)
   if length(in1) ~= ndims(in1{1})
      error('Vector and image dimension do not match.');
   end
   vdim = length(in1); %vector dimension
   if vdim < 2 | vdim > 3
      error('Input only 2D or 3D dip_image_array.');
   end
   if ~isempty(mask)
      vx = mask * in1{1};
      vy = mask * in1{2};
      if vdim == 3
         vz = mask * in1{3};
      end
   else
      vx = in1{1};
      vy = in1{2};
      if vdim == 3
         vz = in1{3};
      end
   end
elseif isa(in1,'dip_image')
   if ~isempty(mask)
      vx = mask * cos(in1);
      vy = mask * sin(in1);
   else
      vx = cos(in1);
      vy = sin(in1);
   end
   if ndims(in1) ==3
      vx = vx * sin(in2);
      vy = vy * sin(in2);
      if ~isempty(mask)
         vz = mask * cos(in2);
      else
         vz = cos(in2);
      end
   end
else
   error('Scalar or vector image expected.')
end
if prod(size(value))==1
   value=repmat(value,1,ndims(vx));
elseif prod(size(value))>3
   error('Subsampling value has wrong dimension.');
end


vx = dip_subsampling(vx, value);
vy = dip_subsampling(vy, value);


figure;
if ndims(vx) ==2
   [x,y] = meshgrid(0:size(vx,1)-1,0:size(vy,2)-1);
   if strcmp(arr,'none')
      quiver(x,y,double(vx),double(vy),scale,'.');
   else
      quiver(x,y,double(vx),double(vy),scale);
   end
else
   vz = dip_subsampling(vz, value);
   [x,y,z] = meshgrid(0:size(vx,1)-1,0:size(vy,2)-1,0:size(vz,3)-1);
   if strcmp(arr,'none')
      quiver3(x,y,z,double(vx),double(vy),double(vz),scale,'.');
   else
      quiver3(x,y,z,double(vx),double(vy),double(vz),scale);
   end
end

axis equal
axis ij %correct for flipped axes
out = 1;
