%OVERLAY   Overlay a grey-value or color image with a binary image
%
% SYNOPSIS:
%  image_out = overlay(grey_in,bin_in,RGB_color)
%
% PARAMETERS:
%  RGB_color: the RGB value of the color to give the binary image.
%
% DEFAULTS:
%  RGB_color = [255,0,0] (red)

% (C) Copyright 1999-2001               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Cris Luengo, May 2001.

function out=overlay(grey,bin,color)

% Handle menu call
if nargin == 1
   if ischar(grey) & strcmp(grey,'DIP_GetParamList')
      out = struct('menu','Display',...
                   'display','Overlay image with mask',...
                   'inparams',struct('name',       {'grey',               'bin',         'color'},...
                                     'description',{'Grey or color image','Binary image','Color'},...
                                     'type',       {'image',              'image',       'array'},...
                                     'dim_check',  {0,                    0,             -1},...
                                     'range_check',{[],                   [],            [0,255]},...
                                     'required',   {1,                    1,             0},...
                                     'default',    {'a',                  'b',           [255,0,0]}...
                                    ),...
                   'outparams',struct('name',{'out'},...
                                      'description',{'Output image'},...
                                      'type',{'image'}...
                                     )...
      );
      return
   end
end

% Parse Input
if nargin < 2
   error('Required input missing.')
end
grey = dip_image(grey);
bin = dip_image(bin,'bin');
if nargin < 3
   color = [255,0,0];
else
   if prod(size(color)) ~= 3
      error('Color must be of the form [R,G,B].')
   end
end

if isa(grey,'dip_image_array')
   % Input is color image
   if ~istensor(grey)
      error('Input image is an array.')
   end
   if ~isequal(size(grey{1}),size(bin))
      error('Sizes do not match.')
   end
   out = colorspace(grey,'RGB');
   out{1}(bin) = color(1);
   out{2}(bin) = color(2);
   out{3}(bin) = color(3);
else
   % Input is grey-value image
   if ~isequal(size(grey),size(bin))
      error('Sizes do not match.')
   end
   out = newimar(grey,grey,grey);
   out{1}(bin) = color(1);
   out{2}(bin) = color(2);
   out{3}(bin) = color(3);
   out = colorspace(out,'RGB');
end
