%OVERLAY   Overlay a grey-value image with a label image
%
% SYNOPSIS:
%  out = overlay_label(in, label)
%
% PARAMETERS:
%  label: label image
%
% EXAMPLE:
%  a = readim('cermet')
%  b = label(threshold(max(a)-a))
%  overlay_label(a,b)
%
% NOTE:
%  This may take a while for large images and/or many labels

% (C) Copyright 1999-2004               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, Jan 2004.

function out=overlay_label(grey,bin)

if nargin == 1
   if ischar(grey) & strcmp(grey,'DIP_GetParamList')
      out = struct('menu','Display',...
     'display','Overlay image with label',...
     'inparams',struct('name',       {'grey',               'bin'        },...
                       'description',{'Grey image',         'Label image'},...
                       'type',       {'image',              'image'      },...
                       'dim_check',  {0,                    0            },...
                       'range_check',{[],                   []           },...
                       'required',   {1,                    1},...
                       'default',    {'a',                  'b'}...
                      ),...
     'outparams',struct('name',{'out'},...
                        'description',{'Output image'},...
                        'type',{'image'}...
                       )...
      );
      return
   end
end

% Parse Input
if nargin < 2
   error('Required input missing.')
end
grey = dip_image(grey);
dt = datatype(bin);
if findstr(dt,'bin') | findstr(dt,'float')
   error('Label must be an integer image.');
end
if isa(grey,'dip_image_array') | isa(bin,'dip_image_array')
   error('Input is a dip_image_array.');
end
if ~isequal(size(grey),size(bin))
      error('Sizes do not match.')
end

N = max(bin);%number of labels
out = newimar(grey,grey,grey);
cm = label_colormap*255;
for ii=1:N
   m = bin==ii;
   jj = mod(ii,255)+1;
   out{1}(m)=cm(jj,1);
   out{2}(m)=cm(jj,2);
   out{3}(m)=cm(jj,3);
end
out = colorspace(out,'RGB');
