%FIND_FILES return sorted files
%
% out = find_files(filebase, ext, start, ending)
%
%  filebase: string containing the base filename
%  ext     : extension
%  start   : first index to read
%  ending  : last index to read 
%
% DEFAUTLS:
%  start  = 0 %start with the first found image
%  ending = 0 %read all found images
%
% 

% (C) Copyright 1999-2004               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, April 2004 (based on CL readstack)
% April 2004, added support for empty extension (BR)
% May 2004, added error if no files are found (BR)

function out=find_files(in,ext,st,ed)
if nargin < 3
   st =0;
   ed =0;
elseif nargin <4
   ed =0;
end

[pathstr,basename] = fileparts(in);
l_ext = length(ext);
if isempty(ext)
   fns = dir([ in '*']);
else
   fns = dir([ in '*.' ext]);
end

if isempty(fns)
   if isempty(ext)
      fns = dir([dipgetpref('ImageFilePath') '/' basename '*']);
   else
      fns = dir([dipgetpref('ImageFilePath') '/' basename '*.' ext]);
   end
end
fns([fns.isdir]) = [];

Nout =  length(fns);
out = cell(1,Nout);
iout = zeros(1,Nout);


if isempty(fns)
   error('No files found');
end
i = strfind(fns(1).name,'_ch0');
if i
   %leica series
   fprintf(' Assuming Leica tiff series.\n');
   l_ext = 8;
   basename = basename(1:i-4);
end

for ii =1:Nout
   out{ii} = fns(ii).name;
   iout(ii) = str2double(out{ii}(length(basename)+1:end-l_ext-1));
end

if st~=0  
   iout(iout < st) = -1; %give smalles value
end
if ed~=0
   iout(iout > ed)  = NaN; % give highest values
end
[iout,I] = sort(iout);
I2 = sum(isnan(iout));
I3 = sum(iout<0);
out = out(I);
out = out(I3+1:end-I2);
[pathstr,basename] = fileparts(in);
if ~isempty(pathstr)
   out = strcat([ pathstr '/'],out);
end
