%READAVI   Reads AVI movie into a 3D image
%  Reads an AVI movie file into a 3D grey-value image, where the z-direction
%  is the time component (only Matlab 6).
%
% SYNOPSIS:
%  out = readavi(filename, frame index, comb)
%
% PARAMETERS:
%  filename:    string with name of file, optionally with path and extension.
%  frame index: array containing the frames to read (possible 1:10, 1:2:10,..)
%  comb:        how to combine the 3 different color channels to one greyvalue image.
%               take the first: 'x1' or combine all 3: '(x1+x2+x3)/3'
%
% DEFAULTS:
%  frame index: read whole movie
%  comb:        take only the first component 'x1'
%


% (C) Copyright 1999-2000               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, May 2001.

function out = readavi(varargin)
d = struct('menu','File I/O',...
           'display','Read avi',...
           'inparams',struct('name',       {'filename',                'frameindex', 'comb'},...
                             'description',{'Name of the file to open','Frame Index', 'Colorchannel combination'},...
                             'type',       {'infile',                  'array',   'option'},...
                             'dim_check',  {0,                         0,0},...
                             'range_check',{'*.*',                     'R+',{'x1','(x1+x2+x3)/3'}},...
                             'required',   {1,                         0,0},...
                             'default',    {'',               0,'x1'}...
                            ),...
           'outparams',struct('name',{'out'},...
                              'description',{'Output image'},...
                              'type',{'image'}...
                              )...
          );


if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      out = d;
      return
   end
end
try
   [filename,frameindex,comb] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end

if frameindex==0
   a = aviread(filename);
   x = dip_image(cat(4,a.cdata));
else
   a = aviread(filename,frameindex);
   x = dip_image(a.cdata);
end
if ndims(x)==3
   x = reshape(x,[size(x),1]);
elseif ndims(x)==2
   x = reshape(x,[size(x),1,1]);
end
% We are not using the a.colormap here!!!
% So if an AVI file uses a colormap, things go completely wrong...
if strcmp(comb,'x1')
   out = squeeze(x(:,:,1,:));
else
   out = squeeze(sum(x,[],3)/size(x,3));
end
