%RECONSTRUCTION   Morphological reconstruction by dilation
%
% SYNOPSIS:
%  out = reconstruction(marker,mask)
%
% PARAMETERS:
%  marker: seed image for reconstruction
%  mask:   image to be reconstructed
%
% EXAMPLE:
%  a = readim
%  b = a>200
%  c = reconstruction(a*b,a)


% (C) Copyright 1999-2002               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, March 2002.
% Changed name and parameter order, Cris Luengo, April 2002.

function out = reconstruction(varargin)

d = struct('menu','Morphology',...
  'display','Reconstruction by Dilation',...
  'inparams',struct('name',       {'marker',   'mask'},...
    'description',{'Marker image','Mask image'},...
    'type',       {'image',      'image'},...
    'dim_check',  {0,            0},...
    'range_check',{[],           []},...
    'required',   {1,            1},...
    'default',    {'a',          'b'}...
   ),...
  'outparams',struct('name',{'out'},...
                     'description',{'Output image'},...
                     'type',{'image'}...
                     )...
 );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      out = d;
      return
   end
end
try
   [marker,mask] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end

out = dip_morphologicalreconstruction(marker,mask);
