%SHIFT   Shift an image
%
% The shift is done via the Fourier domain.
% out = Real(InvFT( FT(translation) * FTm( in ))
%
% SYNOPSIS:
%  image_out = shift(image_in, translation)
%
% PARAMETERS:
%  translation = 1 x n array containing the shift

% (C) Copyright 1999-2001               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, March 2001.

function image_out = shift(varargin)

d = struct('menu','Manipulation',...
           'display','Shift',...
           'inparams',struct('name',       {'image_in',   'trans'},...
                             'description',{'Input image','Translation'},...
                             'type',       {'image',      'array'},...
                             'dim_check',  {0,            1},...
                             'range_check',{[],           'R'},...
                             'required',   {1,            0},...
                             'default',    {'a',          1}...
                            ),...
           'outparams',struct('name',{'image_out'},...
                              'description',{'Output image'},...
                              'type',{'image'}...
                              )...
          );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      image_out = d;
      return
   end
end
try
   [image_in,trans] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end
image_out = dip_shift(image_in,trans);
