%WATERSHED   Watershed
%
% SYNOPSIS:
%  image_out = watershed(image_in,connectivity,max_depth,max_size)
%
% PARAMETERS:
%  connectivity: defines the metric.
%     * 1 indicates city-block metric, or a diamond-shaped S.E.
%     * 2 indicates chessboard metric, or a square structuring element (in 2D).
%  max_depth, max_size: determine merging of regions.
%     A region smaller than min_size and less deep than max_depth will
%     be merged.
%
% DEFAULTS:
%  connectivity = 1
%  max_depth = 0 (no merging)
%  max_size = 2e9 (very large indeed)
%
% NOTE:
%  Only images with 1 to 3 dimensions are supported.

% (C) Copyright 1999-2001               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Cris Luengo, July 2001.

function image_out = watershed(varargin)

d = struct('menu','Morphology',...
           'display','Watershed',...
           'inparams',struct('name',       {'image_in',   'connectivity','max_depth',                'max_size'},...
                             'description',{'Input image','Connectivity','Maximum depth for merging','Maximum size for merging'},...
                             'type',       {'image',      'array',       'array',                    'array'},...
                             'dim_check',  {0,            0,             0,                          0},...
                             'range_check',{[],           'N+',           'R+',                       'N'},...
                             'required',   {1,            0,             0,                          0},...
                             'default',    {'a',          1,             0,                          2e9}...
                            ),...
           'outparams',struct('name',{'image_out'},...
                              'description',{'Output image'},...
                              'type',{'image'}...
                              )...
          );
if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      image_out = d;
      return
   end
end
try
   [image_in,connectivity,max_depth,max_size] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end

image_out = dip_watershed(image_in,[],connectivity,max_depth,max_size);
