%WRITEAVI   Writes 3D image into an AVI file
%  Writes a 3D grey-value image into an avi movie file, where the z-direction
%  is the time component (only Matlab 6).
%
% SYNOPSIS:
%  writeavi(image_in, filename, fps, fignum)
%
% PARAMETERS:
%  image_in: image to write to file.
%  filename: string with name of file, optionally with path and extension.
%  fps:      frames per second to write
%  fignum:   Number of the figure window that the image should be displayed in
%
% DEFAULTS:
%  fps = 15
%  fignum = 10

% (C) Copyright 1999-2000               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Bernd Rieger, May 2001.
function out = writedisplayavi(varargin)

compressionopts={'None'};
comdef = compressionopts;
if ispc
   compressionopts={ 'None', 'Indeo3', 'Indeo5', 'Cinepak', 'MSVC', 'RLE' };
   compdef = 'Cinepak';
end
d = struct('menu','File I/O',...
           'display','Write avi',...
           'inparams',struct('name',       {'in',              'filename',                   'fps',               'fignumber',     'compression'},...
                             'description',{'Image to write',  'Name of the file to write',  'Frames per second', 'Figure number', 'Compression method'},...
                             'type',       {'image',           'outfile',                    'array',             'array',         'option'},...
                             'dim_check',  {0,               0,                  0,    0,    0},...
                             'range_check',{[],              '*.*',              'R+', 'R+', compressionopts},...
                             'required',   {1,               1,                  0,    0,    0},...
                             'default',    {'a',             '',                 15,   10,   'None'}...
                            )...
          );


if nargin == 1
   s = varargin{1};
   if ischar(s) & strcmp(s,'DIP_GetParamList')
      out = d;
      return
   end
end
try
   [in,filename,fps,fignumber,compression] = getparams(d,varargin{:});
catch
   if ~isempty(paramerror)
      error(paramerror)
   else
      error(firsterr)
   end
end
if ndims(in) ~= 3
   error('Input image must be 3D.');
end

aviobj = avifile(filename,'fps',fps,'compression',compression);

windowname = get(fignumber);
windowname = windowname.UserData.imname;

for ii =0:size(in,3)-1
   s = [ windowname '=squeeze(in(:,:,ii))'];
   eval(s)
   frame = getframe(gca);
   aviobj = addframe(aviobj, frame);
end
aviobj = close(aviobj);

