%dip_initialise   Initialises the DIPlib library
%   dip_initialise must be called before using any of the DIPlib
%   functions. When DIPlib is no longer needed, a call to
%   dip_exit will remove DIPlib from memory.

% (C) Copyright 1999-2004               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Cris Luengo, June 2000.
% 19 April 2001: The error message is more helpful now in case of
%                wrong installation.
% 30 May 2004: Renamed the private MEX-file dip__initialise to avoid
%              confusing problems with dip_initialise.m .

function dip_initialise(mode)

v = version;
ii = find(v=='.');
if length(ii)>1
   v = v(1:ii(2)-1);
end
ii = find(v==' ');
if ~isempty(ii)
   v = v(1:ii(1)-1);
end
v = eval(v);
if v < 5.3
   error('MATLAB 5.3 (Release 11) or later required');
end

try
   dip__initialise(1);
catch
   if ~isempty(findstr(lasterr,'This version of DIPlib has expired.'))
      disp(' ')
      disp(' ')
      disp(['   This version of DIPimage has expired. Please visit';...
            '      http://www.ph.tn.tudelft.nl/DIPlib             ';...
            '   to obtain a new version.                          '])
      disp(' ')
      disp(' ')
      error('DIPlib has expired.')
   else
      disp(' ')
      disp(['   Initialisation of DIPlib failed. The most probable cause is';...
            '   incorrect installation. Please make sure that:             ';...
            '   - You are running MATLAB version 5.3 (Release 11) or later.';...
            '   - DIPlib is supported on your operating system.            ';...
            '   - These three files can be found by your system:           '])
      if strcmp(computer,'PCWIN')
         disp('       libdip.dll, libdipio.dll, libdml.dll')
         if v>=6
            disp(['       (they must be in the ',matlabroot,'\bin\win32 directory or']);
         else
            disp(['       (they must be in the ',matlabroot,'\bin directory or']);
         end
         disp('       any directory on your PATH).')
      else
         disp(['       libdip.so, libdipio.so, libdml.so.                      ';...
               '       (they must be in any directory on your LD_LIBRARY_PATH).'])
      end
      disp(['   - These files are the correct version (not newer or older to the';...
            '     ones provided with the toolbox).                              ';...
            '                                                                   ';...
            '   Please read the manual for more information on installing this  ';...
            '   toolbox. It can be found at:                                    ';...
            '       http://www.ph.tn.tudelft.nl/DIPlib/docs/dipimage.pdf        '])
      disp(' ')
      disp(' ')
      error('Initialisation of DIPlib failed.')
   end
end

if nargin == 1 & ischar(mode) & strcmpi(mode,'silent')
   return
end

dipInfo = dip_getlibraryinformation;
fprintf('\n%s %s (%s - %s)\n',dipInfo.name,dipInfo.version,dipInfo.date,dipInfo.type);
fprintf('    %s\n',dipInfo.description);
fprintf('    %s\n',dipInfo.copyright);
fprintf('    %s\n\n',dipInfo.contact);

days_left = dipInfo.days_left;
isdemo = days_left >= 0;

dipInfo = dipio_getlibraryinformation;
fprintf('\n%s %s (%s - %s)\n',dipInfo.name,dipInfo.version,dipInfo.date,dipInfo.type);
fprintf('    %s\n',dipInfo.description);
fprintf('    %s\n',dipInfo.copyright);
fprintf('    %s\n\n',dipInfo.contact);

if isdemo
   fprintf('\nDIPlib with time limit: %d days left.\n\n',days_left);
end
